/*
 * This file is generated by gdbus-codegen, do not modify it.
 *
 * The license of this code is the same as for the D-Bus interface description
 * it was derived from. Note that it links to GLib, so must comply with the
 * LGPL linking clauses.
 */

#ifndef __SHELL_DBUS_H__
#define __SHELL_DBUS_H__

#include <gio/gio.h>

G_BEGIN_DECLS


/* ------------------------------------------------------------------------ */
/* Declarations for org.freedesktop.Accounts.User */

#define TYPE_ORG_FREEDESKTOP_ACCOUNTS_USER (org_freedesktop_accounts_user_get_type ())
#define ORG_FREEDESKTOP_ACCOUNTS_USER(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), TYPE_ORG_FREEDESKTOP_ACCOUNTS_USER, OrgFreedesktopAccountsUser))
#define IS_ORG_FREEDESKTOP_ACCOUNTS_USER(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), TYPE_ORG_FREEDESKTOP_ACCOUNTS_USER))
#define ORG_FREEDESKTOP_ACCOUNTS_USER_GET_IFACE(o) (G_TYPE_INSTANCE_GET_INTERFACE ((o), TYPE_ORG_FREEDESKTOP_ACCOUNTS_USER, OrgFreedesktopAccountsUserIface))

struct _OrgFreedesktopAccountsUser;
typedef struct _OrgFreedesktopAccountsUser OrgFreedesktopAccountsUser;
typedef struct _OrgFreedesktopAccountsUserIface OrgFreedesktopAccountsUserIface;

struct _OrgFreedesktopAccountsUserIface
{
  GTypeInterface parent_iface;



  gboolean (*handle_set_account_type) (
    OrgFreedesktopAccountsUser *object,
    GDBusMethodInvocation *invocation,
    gint arg_accountType);

  gboolean (*handle_set_automatic_login) (
    OrgFreedesktopAccountsUser *object,
    GDBusMethodInvocation *invocation,
    gboolean arg_enabled);

  gboolean (*handle_set_email) (
    OrgFreedesktopAccountsUser *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_email);

  gboolean (*handle_set_home_directory) (
    OrgFreedesktopAccountsUser *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_homedir);

  gboolean (*handle_set_icon_file) (
    OrgFreedesktopAccountsUser *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_filename);

  gboolean (*handle_set_language) (
    OrgFreedesktopAccountsUser *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_language);

  gboolean (*handle_set_location) (
    OrgFreedesktopAccountsUser *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_location);

  gboolean (*handle_set_locked) (
    OrgFreedesktopAccountsUser *object,
    GDBusMethodInvocation *invocation,
    gboolean arg_locked);

  gboolean (*handle_set_password) (
    OrgFreedesktopAccountsUser *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_password,
    const gchar *arg_hint);

  gboolean (*handle_set_password_hint) (
    OrgFreedesktopAccountsUser *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_hint);

  gboolean (*handle_set_password_mode) (
    OrgFreedesktopAccountsUser *object,
    GDBusMethodInvocation *invocation,
    gint arg_mode);

  gboolean (*handle_set_real_name) (
    OrgFreedesktopAccountsUser *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_name);

  gboolean (*handle_set_shell) (
    OrgFreedesktopAccountsUser *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_shell);

  gboolean (*handle_set_user_name) (
    OrgFreedesktopAccountsUser *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_name);

  gboolean (*handle_set_xsession) (
    OrgFreedesktopAccountsUser *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_x_session);

  gint  (*get_account_type) (OrgFreedesktopAccountsUser *object);

  gboolean  (*get_automatic_login) (OrgFreedesktopAccountsUser *object);

  const gchar * (*get_email) (OrgFreedesktopAccountsUser *object);

  const gchar * (*get_home_directory) (OrgFreedesktopAccountsUser *object);

  const gchar * (*get_icon_file) (OrgFreedesktopAccountsUser *object);

  const gchar * (*get_language) (OrgFreedesktopAccountsUser *object);

  gboolean  (*get_local_account) (OrgFreedesktopAccountsUser *object);

  const gchar * (*get_location) (OrgFreedesktopAccountsUser *object);

  gboolean  (*get_locked) (OrgFreedesktopAccountsUser *object);

  guint64  (*get_login_frequency) (OrgFreedesktopAccountsUser *object);

  GVariant * (*get_login_history) (OrgFreedesktopAccountsUser *object);

  gint64  (*get_login_time) (OrgFreedesktopAccountsUser *object);

  const gchar * (*get_password_hint) (OrgFreedesktopAccountsUser *object);

  gint  (*get_password_mode) (OrgFreedesktopAccountsUser *object);

  const gchar * (*get_real_name) (OrgFreedesktopAccountsUser *object);

  const gchar * (*get_shell) (OrgFreedesktopAccountsUser *object);

  gboolean  (*get_system_account) (OrgFreedesktopAccountsUser *object);

  guint64  (*get_uid) (OrgFreedesktopAccountsUser *object);

  const gchar * (*get_user_name) (OrgFreedesktopAccountsUser *object);

  const gchar * (*get_xsession) (OrgFreedesktopAccountsUser *object);

  void (*changed) (
    OrgFreedesktopAccountsUser *object);

};

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (OrgFreedesktopAccountsUser, g_object_unref)
#endif

GType org_freedesktop_accounts_user_get_type (void) G_GNUC_CONST;

GDBusInterfaceInfo *org_freedesktop_accounts_user_interface_info (void);
guint org_freedesktop_accounts_user_override_properties (GObjectClass *klass, guint property_id_begin);


/* D-Bus method call completion functions: */
void org_freedesktop_accounts_user_complete_set_user_name (
    OrgFreedesktopAccountsUser *object,
    GDBusMethodInvocation *invocation);

void org_freedesktop_accounts_user_complete_set_real_name (
    OrgFreedesktopAccountsUser *object,
    GDBusMethodInvocation *invocation);

void org_freedesktop_accounts_user_complete_set_email (
    OrgFreedesktopAccountsUser *object,
    GDBusMethodInvocation *invocation);

void org_freedesktop_accounts_user_complete_set_language (
    OrgFreedesktopAccountsUser *object,
    GDBusMethodInvocation *invocation);

void org_freedesktop_accounts_user_complete_set_xsession (
    OrgFreedesktopAccountsUser *object,
    GDBusMethodInvocation *invocation);

void org_freedesktop_accounts_user_complete_set_location (
    OrgFreedesktopAccountsUser *object,
    GDBusMethodInvocation *invocation);

void org_freedesktop_accounts_user_complete_set_home_directory (
    OrgFreedesktopAccountsUser *object,
    GDBusMethodInvocation *invocation);

void org_freedesktop_accounts_user_complete_set_shell (
    OrgFreedesktopAccountsUser *object,
    GDBusMethodInvocation *invocation);

void org_freedesktop_accounts_user_complete_set_icon_file (
    OrgFreedesktopAccountsUser *object,
    GDBusMethodInvocation *invocation);

void org_freedesktop_accounts_user_complete_set_locked (
    OrgFreedesktopAccountsUser *object,
    GDBusMethodInvocation *invocation);

void org_freedesktop_accounts_user_complete_set_account_type (
    OrgFreedesktopAccountsUser *object,
    GDBusMethodInvocation *invocation);

void org_freedesktop_accounts_user_complete_set_password_mode (
    OrgFreedesktopAccountsUser *object,
    GDBusMethodInvocation *invocation);

void org_freedesktop_accounts_user_complete_set_password (
    OrgFreedesktopAccountsUser *object,
    GDBusMethodInvocation *invocation);

void org_freedesktop_accounts_user_complete_set_password_hint (
    OrgFreedesktopAccountsUser *object,
    GDBusMethodInvocation *invocation);

void org_freedesktop_accounts_user_complete_set_automatic_login (
    OrgFreedesktopAccountsUser *object,
    GDBusMethodInvocation *invocation);



/* D-Bus signal emissions functions: */
void org_freedesktop_accounts_user_emit_changed (
    OrgFreedesktopAccountsUser *object);



/* D-Bus method calls: */
void org_freedesktop_accounts_user_call_set_user_name (
    OrgFreedesktopAccountsUser *proxy,
    const gchar *arg_name,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_freedesktop_accounts_user_call_set_user_name_finish (
    OrgFreedesktopAccountsUser *proxy,
    GAsyncResult *res,
    GError **error);

gboolean org_freedesktop_accounts_user_call_set_user_name_sync (
    OrgFreedesktopAccountsUser *proxy,
    const gchar *arg_name,
    GCancellable *cancellable,
    GError **error);

void org_freedesktop_accounts_user_call_set_real_name (
    OrgFreedesktopAccountsUser *proxy,
    const gchar *arg_name,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_freedesktop_accounts_user_call_set_real_name_finish (
    OrgFreedesktopAccountsUser *proxy,
    GAsyncResult *res,
    GError **error);

gboolean org_freedesktop_accounts_user_call_set_real_name_sync (
    OrgFreedesktopAccountsUser *proxy,
    const gchar *arg_name,
    GCancellable *cancellable,
    GError **error);

void org_freedesktop_accounts_user_call_set_email (
    OrgFreedesktopAccountsUser *proxy,
    const gchar *arg_email,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_freedesktop_accounts_user_call_set_email_finish (
    OrgFreedesktopAccountsUser *proxy,
    GAsyncResult *res,
    GError **error);

gboolean org_freedesktop_accounts_user_call_set_email_sync (
    OrgFreedesktopAccountsUser *proxy,
    const gchar *arg_email,
    GCancellable *cancellable,
    GError **error);

void org_freedesktop_accounts_user_call_set_language (
    OrgFreedesktopAccountsUser *proxy,
    const gchar *arg_language,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_freedesktop_accounts_user_call_set_language_finish (
    OrgFreedesktopAccountsUser *proxy,
    GAsyncResult *res,
    GError **error);

gboolean org_freedesktop_accounts_user_call_set_language_sync (
    OrgFreedesktopAccountsUser *proxy,
    const gchar *arg_language,
    GCancellable *cancellable,
    GError **error);

void org_freedesktop_accounts_user_call_set_xsession (
    OrgFreedesktopAccountsUser *proxy,
    const gchar *arg_x_session,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_freedesktop_accounts_user_call_set_xsession_finish (
    OrgFreedesktopAccountsUser *proxy,
    GAsyncResult *res,
    GError **error);

gboolean org_freedesktop_accounts_user_call_set_xsession_sync (
    OrgFreedesktopAccountsUser *proxy,
    const gchar *arg_x_session,
    GCancellable *cancellable,
    GError **error);

void org_freedesktop_accounts_user_call_set_location (
    OrgFreedesktopAccountsUser *proxy,
    const gchar *arg_location,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_freedesktop_accounts_user_call_set_location_finish (
    OrgFreedesktopAccountsUser *proxy,
    GAsyncResult *res,
    GError **error);

gboolean org_freedesktop_accounts_user_call_set_location_sync (
    OrgFreedesktopAccountsUser *proxy,
    const gchar *arg_location,
    GCancellable *cancellable,
    GError **error);

void org_freedesktop_accounts_user_call_set_home_directory (
    OrgFreedesktopAccountsUser *proxy,
    const gchar *arg_homedir,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_freedesktop_accounts_user_call_set_home_directory_finish (
    OrgFreedesktopAccountsUser *proxy,
    GAsyncResult *res,
    GError **error);

gboolean org_freedesktop_accounts_user_call_set_home_directory_sync (
    OrgFreedesktopAccountsUser *proxy,
    const gchar *arg_homedir,
    GCancellable *cancellable,
    GError **error);

void org_freedesktop_accounts_user_call_set_shell (
    OrgFreedesktopAccountsUser *proxy,
    const gchar *arg_shell,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_freedesktop_accounts_user_call_set_shell_finish (
    OrgFreedesktopAccountsUser *proxy,
    GAsyncResult *res,
    GError **error);

gboolean org_freedesktop_accounts_user_call_set_shell_sync (
    OrgFreedesktopAccountsUser *proxy,
    const gchar *arg_shell,
    GCancellable *cancellable,
    GError **error);

void org_freedesktop_accounts_user_call_set_icon_file (
    OrgFreedesktopAccountsUser *proxy,
    const gchar *arg_filename,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_freedesktop_accounts_user_call_set_icon_file_finish (
    OrgFreedesktopAccountsUser *proxy,
    GAsyncResult *res,
    GError **error);

gboolean org_freedesktop_accounts_user_call_set_icon_file_sync (
    OrgFreedesktopAccountsUser *proxy,
    const gchar *arg_filename,
    GCancellable *cancellable,
    GError **error);

void org_freedesktop_accounts_user_call_set_locked (
    OrgFreedesktopAccountsUser *proxy,
    gboolean arg_locked,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_freedesktop_accounts_user_call_set_locked_finish (
    OrgFreedesktopAccountsUser *proxy,
    GAsyncResult *res,
    GError **error);

gboolean org_freedesktop_accounts_user_call_set_locked_sync (
    OrgFreedesktopAccountsUser *proxy,
    gboolean arg_locked,
    GCancellable *cancellable,
    GError **error);

void org_freedesktop_accounts_user_call_set_account_type (
    OrgFreedesktopAccountsUser *proxy,
    gint arg_accountType,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_freedesktop_accounts_user_call_set_account_type_finish (
    OrgFreedesktopAccountsUser *proxy,
    GAsyncResult *res,
    GError **error);

gboolean org_freedesktop_accounts_user_call_set_account_type_sync (
    OrgFreedesktopAccountsUser *proxy,
    gint arg_accountType,
    GCancellable *cancellable,
    GError **error);

void org_freedesktop_accounts_user_call_set_password_mode (
    OrgFreedesktopAccountsUser *proxy,
    gint arg_mode,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_freedesktop_accounts_user_call_set_password_mode_finish (
    OrgFreedesktopAccountsUser *proxy,
    GAsyncResult *res,
    GError **error);

gboolean org_freedesktop_accounts_user_call_set_password_mode_sync (
    OrgFreedesktopAccountsUser *proxy,
    gint arg_mode,
    GCancellable *cancellable,
    GError **error);

void org_freedesktop_accounts_user_call_set_password (
    OrgFreedesktopAccountsUser *proxy,
    const gchar *arg_password,
    const gchar *arg_hint,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_freedesktop_accounts_user_call_set_password_finish (
    OrgFreedesktopAccountsUser *proxy,
    GAsyncResult *res,
    GError **error);

gboolean org_freedesktop_accounts_user_call_set_password_sync (
    OrgFreedesktopAccountsUser *proxy,
    const gchar *arg_password,
    const gchar *arg_hint,
    GCancellable *cancellable,
    GError **error);

void org_freedesktop_accounts_user_call_set_password_hint (
    OrgFreedesktopAccountsUser *proxy,
    const gchar *arg_hint,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_freedesktop_accounts_user_call_set_password_hint_finish (
    OrgFreedesktopAccountsUser *proxy,
    GAsyncResult *res,
    GError **error);

gboolean org_freedesktop_accounts_user_call_set_password_hint_sync (
    OrgFreedesktopAccountsUser *proxy,
    const gchar *arg_hint,
    GCancellable *cancellable,
    GError **error);

void org_freedesktop_accounts_user_call_set_automatic_login (
    OrgFreedesktopAccountsUser *proxy,
    gboolean arg_enabled,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_freedesktop_accounts_user_call_set_automatic_login_finish (
    OrgFreedesktopAccountsUser *proxy,
    GAsyncResult *res,
    GError **error);

gboolean org_freedesktop_accounts_user_call_set_automatic_login_sync (
    OrgFreedesktopAccountsUser *proxy,
    gboolean arg_enabled,
    GCancellable *cancellable,
    GError **error);



/* D-Bus property accessors: */
guint64 org_freedesktop_accounts_user_get_uid (OrgFreedesktopAccountsUser *object);
void org_freedesktop_accounts_user_set_uid (OrgFreedesktopAccountsUser *object, guint64 value);

const gchar *org_freedesktop_accounts_user_get_user_name (OrgFreedesktopAccountsUser *object);
gchar *org_freedesktop_accounts_user_dup_user_name (OrgFreedesktopAccountsUser *object);
void org_freedesktop_accounts_user_set_user_name (OrgFreedesktopAccountsUser *object, const gchar *value);

const gchar *org_freedesktop_accounts_user_get_real_name (OrgFreedesktopAccountsUser *object);
gchar *org_freedesktop_accounts_user_dup_real_name (OrgFreedesktopAccountsUser *object);
void org_freedesktop_accounts_user_set_real_name (OrgFreedesktopAccountsUser *object, const gchar *value);

gint org_freedesktop_accounts_user_get_account_type (OrgFreedesktopAccountsUser *object);
void org_freedesktop_accounts_user_set_account_type (OrgFreedesktopAccountsUser *object, gint value);

const gchar *org_freedesktop_accounts_user_get_home_directory (OrgFreedesktopAccountsUser *object);
gchar *org_freedesktop_accounts_user_dup_home_directory (OrgFreedesktopAccountsUser *object);
void org_freedesktop_accounts_user_set_home_directory (OrgFreedesktopAccountsUser *object, const gchar *value);

const gchar *org_freedesktop_accounts_user_get_shell (OrgFreedesktopAccountsUser *object);
gchar *org_freedesktop_accounts_user_dup_shell (OrgFreedesktopAccountsUser *object);
void org_freedesktop_accounts_user_set_shell (OrgFreedesktopAccountsUser *object, const gchar *value);

const gchar *org_freedesktop_accounts_user_get_email (OrgFreedesktopAccountsUser *object);
gchar *org_freedesktop_accounts_user_dup_email (OrgFreedesktopAccountsUser *object);
void org_freedesktop_accounts_user_set_email (OrgFreedesktopAccountsUser *object, const gchar *value);

const gchar *org_freedesktop_accounts_user_get_language (OrgFreedesktopAccountsUser *object);
gchar *org_freedesktop_accounts_user_dup_language (OrgFreedesktopAccountsUser *object);
void org_freedesktop_accounts_user_set_language (OrgFreedesktopAccountsUser *object, const gchar *value);

const gchar *org_freedesktop_accounts_user_get_xsession (OrgFreedesktopAccountsUser *object);
gchar *org_freedesktop_accounts_user_dup_xsession (OrgFreedesktopAccountsUser *object);
void org_freedesktop_accounts_user_set_xsession (OrgFreedesktopAccountsUser *object, const gchar *value);

const gchar *org_freedesktop_accounts_user_get_location (OrgFreedesktopAccountsUser *object);
gchar *org_freedesktop_accounts_user_dup_location (OrgFreedesktopAccountsUser *object);
void org_freedesktop_accounts_user_set_location (OrgFreedesktopAccountsUser *object, const gchar *value);

guint64 org_freedesktop_accounts_user_get_login_frequency (OrgFreedesktopAccountsUser *object);
void org_freedesktop_accounts_user_set_login_frequency (OrgFreedesktopAccountsUser *object, guint64 value);

gint64 org_freedesktop_accounts_user_get_login_time (OrgFreedesktopAccountsUser *object);
void org_freedesktop_accounts_user_set_login_time (OrgFreedesktopAccountsUser *object, gint64 value);

GVariant *org_freedesktop_accounts_user_get_login_history (OrgFreedesktopAccountsUser *object);
GVariant *org_freedesktop_accounts_user_dup_login_history (OrgFreedesktopAccountsUser *object);
void org_freedesktop_accounts_user_set_login_history (OrgFreedesktopAccountsUser *object, GVariant *value);

const gchar *org_freedesktop_accounts_user_get_icon_file (OrgFreedesktopAccountsUser *object);
gchar *org_freedesktop_accounts_user_dup_icon_file (OrgFreedesktopAccountsUser *object);
void org_freedesktop_accounts_user_set_icon_file (OrgFreedesktopAccountsUser *object, const gchar *value);

gboolean org_freedesktop_accounts_user_get_locked (OrgFreedesktopAccountsUser *object);
void org_freedesktop_accounts_user_set_locked (OrgFreedesktopAccountsUser *object, gboolean value);

gint org_freedesktop_accounts_user_get_password_mode (OrgFreedesktopAccountsUser *object);
void org_freedesktop_accounts_user_set_password_mode (OrgFreedesktopAccountsUser *object, gint value);

const gchar *org_freedesktop_accounts_user_get_password_hint (OrgFreedesktopAccountsUser *object);
gchar *org_freedesktop_accounts_user_dup_password_hint (OrgFreedesktopAccountsUser *object);
void org_freedesktop_accounts_user_set_password_hint (OrgFreedesktopAccountsUser *object, const gchar *value);

gboolean org_freedesktop_accounts_user_get_automatic_login (OrgFreedesktopAccountsUser *object);
void org_freedesktop_accounts_user_set_automatic_login (OrgFreedesktopAccountsUser *object, gboolean value);

gboolean org_freedesktop_accounts_user_get_system_account (OrgFreedesktopAccountsUser *object);
void org_freedesktop_accounts_user_set_system_account (OrgFreedesktopAccountsUser *object, gboolean value);

gboolean org_freedesktop_accounts_user_get_local_account (OrgFreedesktopAccountsUser *object);
void org_freedesktop_accounts_user_set_local_account (OrgFreedesktopAccountsUser *object, gboolean value);


/* ---- */

#define TYPE_ORG_FREEDESKTOP_ACCOUNTS_USER_PROXY (org_freedesktop_accounts_user_proxy_get_type ())
#define ORG_FREEDESKTOP_ACCOUNTS_USER_PROXY(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), TYPE_ORG_FREEDESKTOP_ACCOUNTS_USER_PROXY, OrgFreedesktopAccountsUserProxy))
#define ORG_FREEDESKTOP_ACCOUNTS_USER_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), TYPE_ORG_FREEDESKTOP_ACCOUNTS_USER_PROXY, OrgFreedesktopAccountsUserProxyClass))
#define ORG_FREEDESKTOP_ACCOUNTS_USER_PROXY_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), TYPE_ORG_FREEDESKTOP_ACCOUNTS_USER_PROXY, OrgFreedesktopAccountsUserProxyClass))
#define IS_ORG_FREEDESKTOP_ACCOUNTS_USER_PROXY(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), TYPE_ORG_FREEDESKTOP_ACCOUNTS_USER_PROXY))
#define IS_ORG_FREEDESKTOP_ACCOUNTS_USER_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), TYPE_ORG_FREEDESKTOP_ACCOUNTS_USER_PROXY))

typedef struct _OrgFreedesktopAccountsUserProxy OrgFreedesktopAccountsUserProxy;
typedef struct _OrgFreedesktopAccountsUserProxyClass OrgFreedesktopAccountsUserProxyClass;
typedef struct _OrgFreedesktopAccountsUserProxyPrivate OrgFreedesktopAccountsUserProxyPrivate;

struct _OrgFreedesktopAccountsUserProxy
{
  /*< private >*/
  GDBusProxy parent_instance;
  OrgFreedesktopAccountsUserProxyPrivate *priv;
};

struct _OrgFreedesktopAccountsUserProxyClass
{
  GDBusProxyClass parent_class;
};

GType org_freedesktop_accounts_user_proxy_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (OrgFreedesktopAccountsUserProxy, g_object_unref)
#endif

void org_freedesktop_accounts_user_proxy_new (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
OrgFreedesktopAccountsUser *org_freedesktop_accounts_user_proxy_new_finish (
    GAsyncResult        *res,
    GError             **error);
OrgFreedesktopAccountsUser *org_freedesktop_accounts_user_proxy_new_sync (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);

void org_freedesktop_accounts_user_proxy_new_for_bus (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
OrgFreedesktopAccountsUser *org_freedesktop_accounts_user_proxy_new_for_bus_finish (
    GAsyncResult        *res,
    GError             **error);
OrgFreedesktopAccountsUser *org_freedesktop_accounts_user_proxy_new_for_bus_sync (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);


/* ---- */

#define TYPE_ORG_FREEDESKTOP_ACCOUNTS_USER_SKELETON (org_freedesktop_accounts_user_skeleton_get_type ())
#define ORG_FREEDESKTOP_ACCOUNTS_USER_SKELETON(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), TYPE_ORG_FREEDESKTOP_ACCOUNTS_USER_SKELETON, OrgFreedesktopAccountsUserSkeleton))
#define ORG_FREEDESKTOP_ACCOUNTS_USER_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), TYPE_ORG_FREEDESKTOP_ACCOUNTS_USER_SKELETON, OrgFreedesktopAccountsUserSkeletonClass))
#define ORG_FREEDESKTOP_ACCOUNTS_USER_SKELETON_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), TYPE_ORG_FREEDESKTOP_ACCOUNTS_USER_SKELETON, OrgFreedesktopAccountsUserSkeletonClass))
#define IS_ORG_FREEDESKTOP_ACCOUNTS_USER_SKELETON(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), TYPE_ORG_FREEDESKTOP_ACCOUNTS_USER_SKELETON))
#define IS_ORG_FREEDESKTOP_ACCOUNTS_USER_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), TYPE_ORG_FREEDESKTOP_ACCOUNTS_USER_SKELETON))

typedef struct _OrgFreedesktopAccountsUserSkeleton OrgFreedesktopAccountsUserSkeleton;
typedef struct _OrgFreedesktopAccountsUserSkeletonClass OrgFreedesktopAccountsUserSkeletonClass;
typedef struct _OrgFreedesktopAccountsUserSkeletonPrivate OrgFreedesktopAccountsUserSkeletonPrivate;

struct _OrgFreedesktopAccountsUserSkeleton
{
  /*< private >*/
  GDBusInterfaceSkeleton parent_instance;
  OrgFreedesktopAccountsUserSkeletonPrivate *priv;
};

struct _OrgFreedesktopAccountsUserSkeletonClass
{
  GDBusInterfaceSkeletonClass parent_class;
};

GType org_freedesktop_accounts_user_skeleton_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (OrgFreedesktopAccountsUserSkeleton, g_object_unref)
#endif

OrgFreedesktopAccountsUser *org_freedesktop_accounts_user_skeleton_new (void);


/* ------------------------------------------------------------------------ */
/* Declarations for org.freedesktop.Accounts */

#define TYPE_ORG_FREEDESKTOP_ACCOUNTS (org_freedesktop_accounts_get_type ())
#define ORG_FREEDESKTOP_ACCOUNTS(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), TYPE_ORG_FREEDESKTOP_ACCOUNTS, OrgFreedesktopAccounts))
#define IS_ORG_FREEDESKTOP_ACCOUNTS(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), TYPE_ORG_FREEDESKTOP_ACCOUNTS))
#define ORG_FREEDESKTOP_ACCOUNTS_GET_IFACE(o) (G_TYPE_INSTANCE_GET_INTERFACE ((o), TYPE_ORG_FREEDESKTOP_ACCOUNTS, OrgFreedesktopAccountsIface))

struct _OrgFreedesktopAccounts;
typedef struct _OrgFreedesktopAccounts OrgFreedesktopAccounts;
typedef struct _OrgFreedesktopAccountsIface OrgFreedesktopAccountsIface;

struct _OrgFreedesktopAccountsIface
{
  GTypeInterface parent_iface;



  gboolean (*handle_cache_user) (
    OrgFreedesktopAccounts *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_name);

  gboolean (*handle_create_user) (
    OrgFreedesktopAccounts *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_name,
    const gchar *arg_fullname,
    gint arg_accountType);

  gboolean (*handle_delete_user) (
    OrgFreedesktopAccounts *object,
    GDBusMethodInvocation *invocation,
    gint64 arg_id,
    gboolean arg_removeFiles);

  gboolean (*handle_find_user_by_id) (
    OrgFreedesktopAccounts *object,
    GDBusMethodInvocation *invocation,
    gint64 arg_id);

  gboolean (*handle_find_user_by_name) (
    OrgFreedesktopAccounts *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_name);

  gboolean (*handle_list_cached_users) (
    OrgFreedesktopAccounts *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_uncache_user) (
    OrgFreedesktopAccounts *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_name);

  const gchar * (*get_daemon_version) (OrgFreedesktopAccounts *object);

  void (*user_added) (
    OrgFreedesktopAccounts *object,
    const gchar *arg_user);

  void (*user_deleted) (
    OrgFreedesktopAccounts *object,
    const gchar *arg_user);

};

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (OrgFreedesktopAccounts, g_object_unref)
#endif

GType org_freedesktop_accounts_get_type (void) G_GNUC_CONST;

GDBusInterfaceInfo *org_freedesktop_accounts_interface_info (void);
guint org_freedesktop_accounts_override_properties (GObjectClass *klass, guint property_id_begin);


/* D-Bus method call completion functions: */
void org_freedesktop_accounts_complete_list_cached_users (
    OrgFreedesktopAccounts *object,
    GDBusMethodInvocation *invocation,
    const gchar *const *users);

void org_freedesktop_accounts_complete_find_user_by_id (
    OrgFreedesktopAccounts *object,
    GDBusMethodInvocation *invocation,
    const gchar *user);

void org_freedesktop_accounts_complete_find_user_by_name (
    OrgFreedesktopAccounts *object,
    GDBusMethodInvocation *invocation,
    const gchar *user);

void org_freedesktop_accounts_complete_create_user (
    OrgFreedesktopAccounts *object,
    GDBusMethodInvocation *invocation,
    const gchar *user);

void org_freedesktop_accounts_complete_cache_user (
    OrgFreedesktopAccounts *object,
    GDBusMethodInvocation *invocation,
    const gchar *user);

void org_freedesktop_accounts_complete_uncache_user (
    OrgFreedesktopAccounts *object,
    GDBusMethodInvocation *invocation);

void org_freedesktop_accounts_complete_delete_user (
    OrgFreedesktopAccounts *object,
    GDBusMethodInvocation *invocation);



/* D-Bus signal emissions functions: */
void org_freedesktop_accounts_emit_user_added (
    OrgFreedesktopAccounts *object,
    const gchar *arg_user);

void org_freedesktop_accounts_emit_user_deleted (
    OrgFreedesktopAccounts *object,
    const gchar *arg_user);



/* D-Bus method calls: */
void org_freedesktop_accounts_call_list_cached_users (
    OrgFreedesktopAccounts *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_freedesktop_accounts_call_list_cached_users_finish (
    OrgFreedesktopAccounts *proxy,
    gchar *** out_users,
    GAsyncResult *res,
    GError **error);

gboolean org_freedesktop_accounts_call_list_cached_users_sync (
    OrgFreedesktopAccounts *proxy,
    gchar *** out_users,
    GCancellable *cancellable,
    GError **error);

void org_freedesktop_accounts_call_find_user_by_id (
    OrgFreedesktopAccounts *proxy,
    gint64 arg_id,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_freedesktop_accounts_call_find_user_by_id_finish (
    OrgFreedesktopAccounts *proxy,
    gchar ** out_user,
    GAsyncResult *res,
    GError **error);

gboolean org_freedesktop_accounts_call_find_user_by_id_sync (
    OrgFreedesktopAccounts *proxy,
    gint64 arg_id,
    gchar ** out_user,
    GCancellable *cancellable,
    GError **error);

void org_freedesktop_accounts_call_find_user_by_name (
    OrgFreedesktopAccounts *proxy,
    const gchar *arg_name,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_freedesktop_accounts_call_find_user_by_name_finish (
    OrgFreedesktopAccounts *proxy,
    gchar ** out_user,
    GAsyncResult *res,
    GError **error);

gboolean org_freedesktop_accounts_call_find_user_by_name_sync (
    OrgFreedesktopAccounts *proxy,
    const gchar *arg_name,
    gchar ** out_user,
    GCancellable *cancellable,
    GError **error);

void org_freedesktop_accounts_call_create_user (
    OrgFreedesktopAccounts *proxy,
    const gchar *arg_name,
    const gchar *arg_fullname,
    gint arg_accountType,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_freedesktop_accounts_call_create_user_finish (
    OrgFreedesktopAccounts *proxy,
    gchar ** out_user,
    GAsyncResult *res,
    GError **error);

gboolean org_freedesktop_accounts_call_create_user_sync (
    OrgFreedesktopAccounts *proxy,
    const gchar *arg_name,
    const gchar *arg_fullname,
    gint arg_accountType,
    gchar ** out_user,
    GCancellable *cancellable,
    GError **error);

void org_freedesktop_accounts_call_cache_user (
    OrgFreedesktopAccounts *proxy,
    const gchar *arg_name,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_freedesktop_accounts_call_cache_user_finish (
    OrgFreedesktopAccounts *proxy,
    gchar ** out_user,
    GAsyncResult *res,
    GError **error);

gboolean org_freedesktop_accounts_call_cache_user_sync (
    OrgFreedesktopAccounts *proxy,
    const gchar *arg_name,
    gchar ** out_user,
    GCancellable *cancellable,
    GError **error);

void org_freedesktop_accounts_call_uncache_user (
    OrgFreedesktopAccounts *proxy,
    const gchar *arg_name,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_freedesktop_accounts_call_uncache_user_finish (
    OrgFreedesktopAccounts *proxy,
    GAsyncResult *res,
    GError **error);

gboolean org_freedesktop_accounts_call_uncache_user_sync (
    OrgFreedesktopAccounts *proxy,
    const gchar *arg_name,
    GCancellable *cancellable,
    GError **error);

void org_freedesktop_accounts_call_delete_user (
    OrgFreedesktopAccounts *proxy,
    gint64 arg_id,
    gboolean arg_removeFiles,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_freedesktop_accounts_call_delete_user_finish (
    OrgFreedesktopAccounts *proxy,
    GAsyncResult *res,
    GError **error);

gboolean org_freedesktop_accounts_call_delete_user_sync (
    OrgFreedesktopAccounts *proxy,
    gint64 arg_id,
    gboolean arg_removeFiles,
    GCancellable *cancellable,
    GError **error);



/* D-Bus property accessors: */
const gchar *org_freedesktop_accounts_get_daemon_version (OrgFreedesktopAccounts *object);
gchar *org_freedesktop_accounts_dup_daemon_version (OrgFreedesktopAccounts *object);
void org_freedesktop_accounts_set_daemon_version (OrgFreedesktopAccounts *object, const gchar *value);


/* ---- */

#define TYPE_ORG_FREEDESKTOP_ACCOUNTS_PROXY (org_freedesktop_accounts_proxy_get_type ())
#define ORG_FREEDESKTOP_ACCOUNTS_PROXY(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), TYPE_ORG_FREEDESKTOP_ACCOUNTS_PROXY, OrgFreedesktopAccountsProxy))
#define ORG_FREEDESKTOP_ACCOUNTS_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), TYPE_ORG_FREEDESKTOP_ACCOUNTS_PROXY, OrgFreedesktopAccountsProxyClass))
#define ORG_FREEDESKTOP_ACCOUNTS_PROXY_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), TYPE_ORG_FREEDESKTOP_ACCOUNTS_PROXY, OrgFreedesktopAccountsProxyClass))
#define IS_ORG_FREEDESKTOP_ACCOUNTS_PROXY(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), TYPE_ORG_FREEDESKTOP_ACCOUNTS_PROXY))
#define IS_ORG_FREEDESKTOP_ACCOUNTS_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), TYPE_ORG_FREEDESKTOP_ACCOUNTS_PROXY))

typedef struct _OrgFreedesktopAccountsProxy OrgFreedesktopAccountsProxy;
typedef struct _OrgFreedesktopAccountsProxyClass OrgFreedesktopAccountsProxyClass;
typedef struct _OrgFreedesktopAccountsProxyPrivate OrgFreedesktopAccountsProxyPrivate;

struct _OrgFreedesktopAccountsProxy
{
  /*< private >*/
  GDBusProxy parent_instance;
  OrgFreedesktopAccountsProxyPrivate *priv;
};

struct _OrgFreedesktopAccountsProxyClass
{
  GDBusProxyClass parent_class;
};

GType org_freedesktop_accounts_proxy_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (OrgFreedesktopAccountsProxy, g_object_unref)
#endif

void org_freedesktop_accounts_proxy_new (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
OrgFreedesktopAccounts *org_freedesktop_accounts_proxy_new_finish (
    GAsyncResult        *res,
    GError             **error);
OrgFreedesktopAccounts *org_freedesktop_accounts_proxy_new_sync (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);

void org_freedesktop_accounts_proxy_new_for_bus (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
OrgFreedesktopAccounts *org_freedesktop_accounts_proxy_new_for_bus_finish (
    GAsyncResult        *res,
    GError             **error);
OrgFreedesktopAccounts *org_freedesktop_accounts_proxy_new_for_bus_sync (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);


/* ---- */

#define TYPE_ORG_FREEDESKTOP_ACCOUNTS_SKELETON (org_freedesktop_accounts_skeleton_get_type ())
#define ORG_FREEDESKTOP_ACCOUNTS_SKELETON(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), TYPE_ORG_FREEDESKTOP_ACCOUNTS_SKELETON, OrgFreedesktopAccountsSkeleton))
#define ORG_FREEDESKTOP_ACCOUNTS_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), TYPE_ORG_FREEDESKTOP_ACCOUNTS_SKELETON, OrgFreedesktopAccountsSkeletonClass))
#define ORG_FREEDESKTOP_ACCOUNTS_SKELETON_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), TYPE_ORG_FREEDESKTOP_ACCOUNTS_SKELETON, OrgFreedesktopAccountsSkeletonClass))
#define IS_ORG_FREEDESKTOP_ACCOUNTS_SKELETON(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), TYPE_ORG_FREEDESKTOP_ACCOUNTS_SKELETON))
#define IS_ORG_FREEDESKTOP_ACCOUNTS_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), TYPE_ORG_FREEDESKTOP_ACCOUNTS_SKELETON))

typedef struct _OrgFreedesktopAccountsSkeleton OrgFreedesktopAccountsSkeleton;
typedef struct _OrgFreedesktopAccountsSkeletonClass OrgFreedesktopAccountsSkeletonClass;
typedef struct _OrgFreedesktopAccountsSkeletonPrivate OrgFreedesktopAccountsSkeletonPrivate;

struct _OrgFreedesktopAccountsSkeleton
{
  /*< private >*/
  GDBusInterfaceSkeleton parent_instance;
  OrgFreedesktopAccountsSkeletonPrivate *priv;
};

struct _OrgFreedesktopAccountsSkeletonClass
{
  GDBusInterfaceSkeletonClass parent_class;
};

GType org_freedesktop_accounts_skeleton_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (OrgFreedesktopAccountsSkeleton, g_object_unref)
#endif

OrgFreedesktopAccounts *org_freedesktop_accounts_skeleton_new (void);


/* ------------------------------------------------------------------------ */
/* Declarations for org.gnome.Settings.GlobalShortcutsProvider */

#define TYPE_ORG_GNOME_SETTINGS_GLOBAL_SHORTCUTS_PROVIDER (org_gnome_settings_global_shortcuts_provider_get_type ())
#define ORG_GNOME_SETTINGS_GLOBAL_SHORTCUTS_PROVIDER(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), TYPE_ORG_GNOME_SETTINGS_GLOBAL_SHORTCUTS_PROVIDER, OrgGnomeSettingsGlobalShortcutsProvider))
#define IS_ORG_GNOME_SETTINGS_GLOBAL_SHORTCUTS_PROVIDER(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), TYPE_ORG_GNOME_SETTINGS_GLOBAL_SHORTCUTS_PROVIDER))
#define ORG_GNOME_SETTINGS_GLOBAL_SHORTCUTS_PROVIDER_GET_IFACE(o) (G_TYPE_INSTANCE_GET_INTERFACE ((o), TYPE_ORG_GNOME_SETTINGS_GLOBAL_SHORTCUTS_PROVIDER, OrgGnomeSettingsGlobalShortcutsProviderIface))

struct _OrgGnomeSettingsGlobalShortcutsProvider;
typedef struct _OrgGnomeSettingsGlobalShortcutsProvider OrgGnomeSettingsGlobalShortcutsProvider;
typedef struct _OrgGnomeSettingsGlobalShortcutsProviderIface OrgGnomeSettingsGlobalShortcutsProviderIface;

struct _OrgGnomeSettingsGlobalShortcutsProviderIface
{
  GTypeInterface parent_iface;

  gboolean (*handle_bind_shortcuts) (
    OrgGnomeSettingsGlobalShortcutsProvider *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_app_id,
    const gchar *arg_parent_window,
    GVariant *arg_shortcuts);

};

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (OrgGnomeSettingsGlobalShortcutsProvider, g_object_unref)
#endif

GType org_gnome_settings_global_shortcuts_provider_get_type (void) G_GNUC_CONST;

GDBusInterfaceInfo *org_gnome_settings_global_shortcuts_provider_interface_info (void);
guint org_gnome_settings_global_shortcuts_provider_override_properties (GObjectClass *klass, guint property_id_begin);


/* D-Bus method call completion functions: */
void org_gnome_settings_global_shortcuts_provider_complete_bind_shortcuts (
    OrgGnomeSettingsGlobalShortcutsProvider *object,
    GDBusMethodInvocation *invocation,
    GVariant *results);



/* D-Bus method calls: */
void org_gnome_settings_global_shortcuts_provider_call_bind_shortcuts (
    OrgGnomeSettingsGlobalShortcutsProvider *proxy,
    const gchar *arg_app_id,
    const gchar *arg_parent_window,
    GVariant *arg_shortcuts,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_settings_global_shortcuts_provider_call_bind_shortcuts_finish (
    OrgGnomeSettingsGlobalShortcutsProvider *proxy,
    GVariant ** out_results,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_settings_global_shortcuts_provider_call_bind_shortcuts_sync (
    OrgGnomeSettingsGlobalShortcutsProvider *proxy,
    const gchar *arg_app_id,
    const gchar *arg_parent_window,
    GVariant *arg_shortcuts,
    GVariant ** out_results,
    GCancellable *cancellable,
    GError **error);



/* ---- */

#define TYPE_ORG_GNOME_SETTINGS_GLOBAL_SHORTCUTS_PROVIDER_PROXY (org_gnome_settings_global_shortcuts_provider_proxy_get_type ())
#define ORG_GNOME_SETTINGS_GLOBAL_SHORTCUTS_PROVIDER_PROXY(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), TYPE_ORG_GNOME_SETTINGS_GLOBAL_SHORTCUTS_PROVIDER_PROXY, OrgGnomeSettingsGlobalShortcutsProviderProxy))
#define ORG_GNOME_SETTINGS_GLOBAL_SHORTCUTS_PROVIDER_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), TYPE_ORG_GNOME_SETTINGS_GLOBAL_SHORTCUTS_PROVIDER_PROXY, OrgGnomeSettingsGlobalShortcutsProviderProxyClass))
#define ORG_GNOME_SETTINGS_GLOBAL_SHORTCUTS_PROVIDER_PROXY_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), TYPE_ORG_GNOME_SETTINGS_GLOBAL_SHORTCUTS_PROVIDER_PROXY, OrgGnomeSettingsGlobalShortcutsProviderProxyClass))
#define IS_ORG_GNOME_SETTINGS_GLOBAL_SHORTCUTS_PROVIDER_PROXY(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), TYPE_ORG_GNOME_SETTINGS_GLOBAL_SHORTCUTS_PROVIDER_PROXY))
#define IS_ORG_GNOME_SETTINGS_GLOBAL_SHORTCUTS_PROVIDER_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), TYPE_ORG_GNOME_SETTINGS_GLOBAL_SHORTCUTS_PROVIDER_PROXY))

typedef struct _OrgGnomeSettingsGlobalShortcutsProviderProxy OrgGnomeSettingsGlobalShortcutsProviderProxy;
typedef struct _OrgGnomeSettingsGlobalShortcutsProviderProxyClass OrgGnomeSettingsGlobalShortcutsProviderProxyClass;
typedef struct _OrgGnomeSettingsGlobalShortcutsProviderProxyPrivate OrgGnomeSettingsGlobalShortcutsProviderProxyPrivate;

struct _OrgGnomeSettingsGlobalShortcutsProviderProxy
{
  /*< private >*/
  GDBusProxy parent_instance;
  OrgGnomeSettingsGlobalShortcutsProviderProxyPrivate *priv;
};

struct _OrgGnomeSettingsGlobalShortcutsProviderProxyClass
{
  GDBusProxyClass parent_class;
};

GType org_gnome_settings_global_shortcuts_provider_proxy_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (OrgGnomeSettingsGlobalShortcutsProviderProxy, g_object_unref)
#endif

void org_gnome_settings_global_shortcuts_provider_proxy_new (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
OrgGnomeSettingsGlobalShortcutsProvider *org_gnome_settings_global_shortcuts_provider_proxy_new_finish (
    GAsyncResult        *res,
    GError             **error);
OrgGnomeSettingsGlobalShortcutsProvider *org_gnome_settings_global_shortcuts_provider_proxy_new_sync (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);

void org_gnome_settings_global_shortcuts_provider_proxy_new_for_bus (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
OrgGnomeSettingsGlobalShortcutsProvider *org_gnome_settings_global_shortcuts_provider_proxy_new_for_bus_finish (
    GAsyncResult        *res,
    GError             **error);
OrgGnomeSettingsGlobalShortcutsProvider *org_gnome_settings_global_shortcuts_provider_proxy_new_for_bus_sync (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);


/* ---- */

#define TYPE_ORG_GNOME_SETTINGS_GLOBAL_SHORTCUTS_PROVIDER_SKELETON (org_gnome_settings_global_shortcuts_provider_skeleton_get_type ())
#define ORG_GNOME_SETTINGS_GLOBAL_SHORTCUTS_PROVIDER_SKELETON(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), TYPE_ORG_GNOME_SETTINGS_GLOBAL_SHORTCUTS_PROVIDER_SKELETON, OrgGnomeSettingsGlobalShortcutsProviderSkeleton))
#define ORG_GNOME_SETTINGS_GLOBAL_SHORTCUTS_PROVIDER_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), TYPE_ORG_GNOME_SETTINGS_GLOBAL_SHORTCUTS_PROVIDER_SKELETON, OrgGnomeSettingsGlobalShortcutsProviderSkeletonClass))
#define ORG_GNOME_SETTINGS_GLOBAL_SHORTCUTS_PROVIDER_SKELETON_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), TYPE_ORG_GNOME_SETTINGS_GLOBAL_SHORTCUTS_PROVIDER_SKELETON, OrgGnomeSettingsGlobalShortcutsProviderSkeletonClass))
#define IS_ORG_GNOME_SETTINGS_GLOBAL_SHORTCUTS_PROVIDER_SKELETON(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), TYPE_ORG_GNOME_SETTINGS_GLOBAL_SHORTCUTS_PROVIDER_SKELETON))
#define IS_ORG_GNOME_SETTINGS_GLOBAL_SHORTCUTS_PROVIDER_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), TYPE_ORG_GNOME_SETTINGS_GLOBAL_SHORTCUTS_PROVIDER_SKELETON))

typedef struct _OrgGnomeSettingsGlobalShortcutsProviderSkeleton OrgGnomeSettingsGlobalShortcutsProviderSkeleton;
typedef struct _OrgGnomeSettingsGlobalShortcutsProviderSkeletonClass OrgGnomeSettingsGlobalShortcutsProviderSkeletonClass;
typedef struct _OrgGnomeSettingsGlobalShortcutsProviderSkeletonPrivate OrgGnomeSettingsGlobalShortcutsProviderSkeletonPrivate;

struct _OrgGnomeSettingsGlobalShortcutsProviderSkeleton
{
  /*< private >*/
  GDBusInterfaceSkeleton parent_instance;
  OrgGnomeSettingsGlobalShortcutsProviderSkeletonPrivate *priv;
};

struct _OrgGnomeSettingsGlobalShortcutsProviderSkeletonClass
{
  GDBusInterfaceSkeletonClass parent_class;
};

GType org_gnome_settings_global_shortcuts_provider_skeleton_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (OrgGnomeSettingsGlobalShortcutsProviderSkeleton, g_object_unref)
#endif

OrgGnomeSettingsGlobalShortcutsProvider *org_gnome_settings_global_shortcuts_provider_skeleton_new (void);


/* ------------------------------------------------------------------------ */
/* Declarations for org.gnome.GlobalShortcutsRebind */

#define TYPE_ORG_GNOME_GLOBAL_SHORTCUTS_REBIND (org_gnome_global_shortcuts_rebind_get_type ())
#define ORG_GNOME_GLOBAL_SHORTCUTS_REBIND(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), TYPE_ORG_GNOME_GLOBAL_SHORTCUTS_REBIND, OrgGnomeGlobalShortcutsRebind))
#define IS_ORG_GNOME_GLOBAL_SHORTCUTS_REBIND(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), TYPE_ORG_GNOME_GLOBAL_SHORTCUTS_REBIND))
#define ORG_GNOME_GLOBAL_SHORTCUTS_REBIND_GET_IFACE(o) (G_TYPE_INSTANCE_GET_INTERFACE ((o), TYPE_ORG_GNOME_GLOBAL_SHORTCUTS_REBIND, OrgGnomeGlobalShortcutsRebindIface))

struct _OrgGnomeGlobalShortcutsRebind;
typedef struct _OrgGnomeGlobalShortcutsRebind OrgGnomeGlobalShortcutsRebind;
typedef struct _OrgGnomeGlobalShortcutsRebindIface OrgGnomeGlobalShortcutsRebindIface;

struct _OrgGnomeGlobalShortcutsRebindIface
{
  GTypeInterface parent_iface;

  gboolean (*handle_rebind_shortcuts) (
    OrgGnomeGlobalShortcutsRebind *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_app_id,
    GVariant *arg_shortcuts);

};

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (OrgGnomeGlobalShortcutsRebind, g_object_unref)
#endif

GType org_gnome_global_shortcuts_rebind_get_type (void) G_GNUC_CONST;

GDBusInterfaceInfo *org_gnome_global_shortcuts_rebind_interface_info (void);
guint org_gnome_global_shortcuts_rebind_override_properties (GObjectClass *klass, guint property_id_begin);


/* D-Bus method call completion functions: */
void org_gnome_global_shortcuts_rebind_complete_rebind_shortcuts (
    OrgGnomeGlobalShortcutsRebind *object,
    GDBusMethodInvocation *invocation);



/* D-Bus method calls: */
void org_gnome_global_shortcuts_rebind_call_rebind_shortcuts (
    OrgGnomeGlobalShortcutsRebind *proxy,
    const gchar *arg_app_id,
    GVariant *arg_shortcuts,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_global_shortcuts_rebind_call_rebind_shortcuts_finish (
    OrgGnomeGlobalShortcutsRebind *proxy,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_global_shortcuts_rebind_call_rebind_shortcuts_sync (
    OrgGnomeGlobalShortcutsRebind *proxy,
    const gchar *arg_app_id,
    GVariant *arg_shortcuts,
    GCancellable *cancellable,
    GError **error);



/* ---- */

#define TYPE_ORG_GNOME_GLOBAL_SHORTCUTS_REBIND_PROXY (org_gnome_global_shortcuts_rebind_proxy_get_type ())
#define ORG_GNOME_GLOBAL_SHORTCUTS_REBIND_PROXY(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), TYPE_ORG_GNOME_GLOBAL_SHORTCUTS_REBIND_PROXY, OrgGnomeGlobalShortcutsRebindProxy))
#define ORG_GNOME_GLOBAL_SHORTCUTS_REBIND_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), TYPE_ORG_GNOME_GLOBAL_SHORTCUTS_REBIND_PROXY, OrgGnomeGlobalShortcutsRebindProxyClass))
#define ORG_GNOME_GLOBAL_SHORTCUTS_REBIND_PROXY_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), TYPE_ORG_GNOME_GLOBAL_SHORTCUTS_REBIND_PROXY, OrgGnomeGlobalShortcutsRebindProxyClass))
#define IS_ORG_GNOME_GLOBAL_SHORTCUTS_REBIND_PROXY(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), TYPE_ORG_GNOME_GLOBAL_SHORTCUTS_REBIND_PROXY))
#define IS_ORG_GNOME_GLOBAL_SHORTCUTS_REBIND_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), TYPE_ORG_GNOME_GLOBAL_SHORTCUTS_REBIND_PROXY))

typedef struct _OrgGnomeGlobalShortcutsRebindProxy OrgGnomeGlobalShortcutsRebindProxy;
typedef struct _OrgGnomeGlobalShortcutsRebindProxyClass OrgGnomeGlobalShortcutsRebindProxyClass;
typedef struct _OrgGnomeGlobalShortcutsRebindProxyPrivate OrgGnomeGlobalShortcutsRebindProxyPrivate;

struct _OrgGnomeGlobalShortcutsRebindProxy
{
  /*< private >*/
  GDBusProxy parent_instance;
  OrgGnomeGlobalShortcutsRebindProxyPrivate *priv;
};

struct _OrgGnomeGlobalShortcutsRebindProxyClass
{
  GDBusProxyClass parent_class;
};

GType org_gnome_global_shortcuts_rebind_proxy_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (OrgGnomeGlobalShortcutsRebindProxy, g_object_unref)
#endif

void org_gnome_global_shortcuts_rebind_proxy_new (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
OrgGnomeGlobalShortcutsRebind *org_gnome_global_shortcuts_rebind_proxy_new_finish (
    GAsyncResult        *res,
    GError             **error);
OrgGnomeGlobalShortcutsRebind *org_gnome_global_shortcuts_rebind_proxy_new_sync (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);

void org_gnome_global_shortcuts_rebind_proxy_new_for_bus (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
OrgGnomeGlobalShortcutsRebind *org_gnome_global_shortcuts_rebind_proxy_new_for_bus_finish (
    GAsyncResult        *res,
    GError             **error);
OrgGnomeGlobalShortcutsRebind *org_gnome_global_shortcuts_rebind_proxy_new_for_bus_sync (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);


/* ---- */

#define TYPE_ORG_GNOME_GLOBAL_SHORTCUTS_REBIND_SKELETON (org_gnome_global_shortcuts_rebind_skeleton_get_type ())
#define ORG_GNOME_GLOBAL_SHORTCUTS_REBIND_SKELETON(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), TYPE_ORG_GNOME_GLOBAL_SHORTCUTS_REBIND_SKELETON, OrgGnomeGlobalShortcutsRebindSkeleton))
#define ORG_GNOME_GLOBAL_SHORTCUTS_REBIND_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), TYPE_ORG_GNOME_GLOBAL_SHORTCUTS_REBIND_SKELETON, OrgGnomeGlobalShortcutsRebindSkeletonClass))
#define ORG_GNOME_GLOBAL_SHORTCUTS_REBIND_SKELETON_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), TYPE_ORG_GNOME_GLOBAL_SHORTCUTS_REBIND_SKELETON, OrgGnomeGlobalShortcutsRebindSkeletonClass))
#define IS_ORG_GNOME_GLOBAL_SHORTCUTS_REBIND_SKELETON(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), TYPE_ORG_GNOME_GLOBAL_SHORTCUTS_REBIND_SKELETON))
#define IS_ORG_GNOME_GLOBAL_SHORTCUTS_REBIND_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), TYPE_ORG_GNOME_GLOBAL_SHORTCUTS_REBIND_SKELETON))

typedef struct _OrgGnomeGlobalShortcutsRebindSkeleton OrgGnomeGlobalShortcutsRebindSkeleton;
typedef struct _OrgGnomeGlobalShortcutsRebindSkeletonClass OrgGnomeGlobalShortcutsRebindSkeletonClass;
typedef struct _OrgGnomeGlobalShortcutsRebindSkeletonPrivate OrgGnomeGlobalShortcutsRebindSkeletonPrivate;

struct _OrgGnomeGlobalShortcutsRebindSkeleton
{
  /*< private >*/
  GDBusInterfaceSkeleton parent_instance;
  OrgGnomeGlobalShortcutsRebindSkeletonPrivate *priv;
};

struct _OrgGnomeGlobalShortcutsRebindSkeletonClass
{
  GDBusInterfaceSkeletonClass parent_class;
};

GType org_gnome_global_shortcuts_rebind_skeleton_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (OrgGnomeGlobalShortcutsRebindSkeleton, g_object_unref)
#endif

OrgGnomeGlobalShortcutsRebind *org_gnome_global_shortcuts_rebind_skeleton_new (void);


/* ------------------------------------------------------------------------ */
/* Declarations for org.gnome.Mutter.DisplayConfig */

#define TYPE_ORG_GNOME_MUTTER_DISPLAY_CONFIG (org_gnome_mutter_display_config_get_type ())
#define ORG_GNOME_MUTTER_DISPLAY_CONFIG(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), TYPE_ORG_GNOME_MUTTER_DISPLAY_CONFIG, OrgGnomeMutterDisplayConfig))
#define IS_ORG_GNOME_MUTTER_DISPLAY_CONFIG(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), TYPE_ORG_GNOME_MUTTER_DISPLAY_CONFIG))
#define ORG_GNOME_MUTTER_DISPLAY_CONFIG_GET_IFACE(o) (G_TYPE_INSTANCE_GET_INTERFACE ((o), TYPE_ORG_GNOME_MUTTER_DISPLAY_CONFIG, OrgGnomeMutterDisplayConfigIface))

struct _OrgGnomeMutterDisplayConfig;
typedef struct _OrgGnomeMutterDisplayConfig OrgGnomeMutterDisplayConfig;
typedef struct _OrgGnomeMutterDisplayConfigIface OrgGnomeMutterDisplayConfigIface;

struct _OrgGnomeMutterDisplayConfigIface
{
  GTypeInterface parent_iface;



  gboolean (*handle_apply_configuration) (
    OrgGnomeMutterDisplayConfig *object,
    GDBusMethodInvocation *invocation,
    guint arg_serial,
    gboolean arg_persistent,
    GVariant *arg_crtcs,
    GVariant *arg_outputs);

  gboolean (*handle_apply_monitors_config) (
    OrgGnomeMutterDisplayConfig *object,
    GDBusMethodInvocation *invocation,
    guint arg_serial,
    guint arg_method,
    GVariant *arg_logical_monitors,
    GVariant *arg_properties);

  gboolean (*handle_change_backlight) (
    OrgGnomeMutterDisplayConfig *object,
    GDBusMethodInvocation *invocation,
    guint arg_serial,
    guint arg_output,
    gint arg_value);

  gboolean (*handle_get_crtc_gamma) (
    OrgGnomeMutterDisplayConfig *object,
    GDBusMethodInvocation *invocation,
    guint arg_serial,
    guint arg_crtc);

  gboolean (*handle_get_current_state) (
    OrgGnomeMutterDisplayConfig *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_get_resources) (
    OrgGnomeMutterDisplayConfig *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_set_crtc_gamma) (
    OrgGnomeMutterDisplayConfig *object,
    GDBusMethodInvocation *invocation,
    guint arg_serial,
    guint arg_crtc,
    GVariant *arg_red,
    GVariant *arg_green,
    GVariant *arg_blue);

  gint  (*get_power_save_mode) (OrgGnomeMutterDisplayConfig *object);

  void (*monitors_changed) (
    OrgGnomeMutterDisplayConfig *object);

};

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (OrgGnomeMutterDisplayConfig, g_object_unref)
#endif

GType org_gnome_mutter_display_config_get_type (void) G_GNUC_CONST;

GDBusInterfaceInfo *org_gnome_mutter_display_config_interface_info (void);
guint org_gnome_mutter_display_config_override_properties (GObjectClass *klass, guint property_id_begin);


/* D-Bus method call completion functions: */
void org_gnome_mutter_display_config_complete_get_resources (
    OrgGnomeMutterDisplayConfig *object,
    GDBusMethodInvocation *invocation,
    guint serial,
    GVariant *crtcs,
    GVariant *outputs,
    GVariant *modes,
    gint max_screen_width,
    gint max_screen_height);

void org_gnome_mutter_display_config_complete_apply_configuration (
    OrgGnomeMutterDisplayConfig *object,
    GDBusMethodInvocation *invocation);

void org_gnome_mutter_display_config_complete_change_backlight (
    OrgGnomeMutterDisplayConfig *object,
    GDBusMethodInvocation *invocation,
    gint new_value);

void org_gnome_mutter_display_config_complete_get_crtc_gamma (
    OrgGnomeMutterDisplayConfig *object,
    GDBusMethodInvocation *invocation,
    GVariant *red,
    GVariant *green,
    GVariant *blue);

void org_gnome_mutter_display_config_complete_set_crtc_gamma (
    OrgGnomeMutterDisplayConfig *object,
    GDBusMethodInvocation *invocation);

void org_gnome_mutter_display_config_complete_get_current_state (
    OrgGnomeMutterDisplayConfig *object,
    GDBusMethodInvocation *invocation,
    guint serial,
    GVariant *monitors,
    GVariant *logical_monitors,
    GVariant *properties);

void org_gnome_mutter_display_config_complete_apply_monitors_config (
    OrgGnomeMutterDisplayConfig *object,
    GDBusMethodInvocation *invocation);



/* D-Bus signal emissions functions: */
void org_gnome_mutter_display_config_emit_monitors_changed (
    OrgGnomeMutterDisplayConfig *object);



/* D-Bus method calls: */
void org_gnome_mutter_display_config_call_get_resources (
    OrgGnomeMutterDisplayConfig *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_mutter_display_config_call_get_resources_finish (
    OrgGnomeMutterDisplayConfig *proxy,
    guint* out_serial,
    GVariant ** out_crtcs,
    GVariant ** out_outputs,
    GVariant ** out_modes,
    gint* out_max_screen_width,
    gint* out_max_screen_height,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_mutter_display_config_call_get_resources_sync (
    OrgGnomeMutterDisplayConfig *proxy,
    guint* out_serial,
    GVariant ** out_crtcs,
    GVariant ** out_outputs,
    GVariant ** out_modes,
    gint* out_max_screen_width,
    gint* out_max_screen_height,
    GCancellable *cancellable,
    GError **error);

void org_gnome_mutter_display_config_call_apply_configuration (
    OrgGnomeMutterDisplayConfig *proxy,
    guint arg_serial,
    gboolean arg_persistent,
    GVariant *arg_crtcs,
    GVariant *arg_outputs,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_mutter_display_config_call_apply_configuration_finish (
    OrgGnomeMutterDisplayConfig *proxy,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_mutter_display_config_call_apply_configuration_sync (
    OrgGnomeMutterDisplayConfig *proxy,
    guint arg_serial,
    gboolean arg_persistent,
    GVariant *arg_crtcs,
    GVariant *arg_outputs,
    GCancellable *cancellable,
    GError **error);

void org_gnome_mutter_display_config_call_change_backlight (
    OrgGnomeMutterDisplayConfig *proxy,
    guint arg_serial,
    guint arg_output,
    gint arg_value,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_mutter_display_config_call_change_backlight_finish (
    OrgGnomeMutterDisplayConfig *proxy,
    gint* out_new_value,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_mutter_display_config_call_change_backlight_sync (
    OrgGnomeMutterDisplayConfig *proxy,
    guint arg_serial,
    guint arg_output,
    gint arg_value,
    gint* out_new_value,
    GCancellable *cancellable,
    GError **error);

void org_gnome_mutter_display_config_call_get_crtc_gamma (
    OrgGnomeMutterDisplayConfig *proxy,
    guint arg_serial,
    guint arg_crtc,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_mutter_display_config_call_get_crtc_gamma_finish (
    OrgGnomeMutterDisplayConfig *proxy,
    GVariant ** out_red,
    GVariant ** out_green,
    GVariant ** out_blue,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_mutter_display_config_call_get_crtc_gamma_sync (
    OrgGnomeMutterDisplayConfig *proxy,
    guint arg_serial,
    guint arg_crtc,
    GVariant ** out_red,
    GVariant ** out_green,
    GVariant ** out_blue,
    GCancellable *cancellable,
    GError **error);

void org_gnome_mutter_display_config_call_set_crtc_gamma (
    OrgGnomeMutterDisplayConfig *proxy,
    guint arg_serial,
    guint arg_crtc,
    GVariant *arg_red,
    GVariant *arg_green,
    GVariant *arg_blue,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_mutter_display_config_call_set_crtc_gamma_finish (
    OrgGnomeMutterDisplayConfig *proxy,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_mutter_display_config_call_set_crtc_gamma_sync (
    OrgGnomeMutterDisplayConfig *proxy,
    guint arg_serial,
    guint arg_crtc,
    GVariant *arg_red,
    GVariant *arg_green,
    GVariant *arg_blue,
    GCancellable *cancellable,
    GError **error);

void org_gnome_mutter_display_config_call_get_current_state (
    OrgGnomeMutterDisplayConfig *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_mutter_display_config_call_get_current_state_finish (
    OrgGnomeMutterDisplayConfig *proxy,
    guint* out_serial,
    GVariant ** out_monitors,
    GVariant ** out_logical_monitors,
    GVariant ** out_properties,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_mutter_display_config_call_get_current_state_sync (
    OrgGnomeMutterDisplayConfig *proxy,
    guint* out_serial,
    GVariant ** out_monitors,
    GVariant ** out_logical_monitors,
    GVariant ** out_properties,
    GCancellable *cancellable,
    GError **error);

void org_gnome_mutter_display_config_call_apply_monitors_config (
    OrgGnomeMutterDisplayConfig *proxy,
    guint arg_serial,
    guint arg_method,
    GVariant *arg_logical_monitors,
    GVariant *arg_properties,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_mutter_display_config_call_apply_monitors_config_finish (
    OrgGnomeMutterDisplayConfig *proxy,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_mutter_display_config_call_apply_monitors_config_sync (
    OrgGnomeMutterDisplayConfig *proxy,
    guint arg_serial,
    guint arg_method,
    GVariant *arg_logical_monitors,
    GVariant *arg_properties,
    GCancellable *cancellable,
    GError **error);



/* D-Bus property accessors: */
gint org_gnome_mutter_display_config_get_power_save_mode (OrgGnomeMutterDisplayConfig *object);
void org_gnome_mutter_display_config_set_power_save_mode (OrgGnomeMutterDisplayConfig *object, gint value);


/* ---- */

#define TYPE_ORG_GNOME_MUTTER_DISPLAY_CONFIG_PROXY (org_gnome_mutter_display_config_proxy_get_type ())
#define ORG_GNOME_MUTTER_DISPLAY_CONFIG_PROXY(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), TYPE_ORG_GNOME_MUTTER_DISPLAY_CONFIG_PROXY, OrgGnomeMutterDisplayConfigProxy))
#define ORG_GNOME_MUTTER_DISPLAY_CONFIG_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), TYPE_ORG_GNOME_MUTTER_DISPLAY_CONFIG_PROXY, OrgGnomeMutterDisplayConfigProxyClass))
#define ORG_GNOME_MUTTER_DISPLAY_CONFIG_PROXY_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), TYPE_ORG_GNOME_MUTTER_DISPLAY_CONFIG_PROXY, OrgGnomeMutterDisplayConfigProxyClass))
#define IS_ORG_GNOME_MUTTER_DISPLAY_CONFIG_PROXY(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), TYPE_ORG_GNOME_MUTTER_DISPLAY_CONFIG_PROXY))
#define IS_ORG_GNOME_MUTTER_DISPLAY_CONFIG_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), TYPE_ORG_GNOME_MUTTER_DISPLAY_CONFIG_PROXY))

typedef struct _OrgGnomeMutterDisplayConfigProxy OrgGnomeMutterDisplayConfigProxy;
typedef struct _OrgGnomeMutterDisplayConfigProxyClass OrgGnomeMutterDisplayConfigProxyClass;
typedef struct _OrgGnomeMutterDisplayConfigProxyPrivate OrgGnomeMutterDisplayConfigProxyPrivate;

struct _OrgGnomeMutterDisplayConfigProxy
{
  /*< private >*/
  GDBusProxy parent_instance;
  OrgGnomeMutterDisplayConfigProxyPrivate *priv;
};

struct _OrgGnomeMutterDisplayConfigProxyClass
{
  GDBusProxyClass parent_class;
};

GType org_gnome_mutter_display_config_proxy_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (OrgGnomeMutterDisplayConfigProxy, g_object_unref)
#endif

void org_gnome_mutter_display_config_proxy_new (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
OrgGnomeMutterDisplayConfig *org_gnome_mutter_display_config_proxy_new_finish (
    GAsyncResult        *res,
    GError             **error);
OrgGnomeMutterDisplayConfig *org_gnome_mutter_display_config_proxy_new_sync (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);

void org_gnome_mutter_display_config_proxy_new_for_bus (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
OrgGnomeMutterDisplayConfig *org_gnome_mutter_display_config_proxy_new_for_bus_finish (
    GAsyncResult        *res,
    GError             **error);
OrgGnomeMutterDisplayConfig *org_gnome_mutter_display_config_proxy_new_for_bus_sync (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);


/* ---- */

#define TYPE_ORG_GNOME_MUTTER_DISPLAY_CONFIG_SKELETON (org_gnome_mutter_display_config_skeleton_get_type ())
#define ORG_GNOME_MUTTER_DISPLAY_CONFIG_SKELETON(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), TYPE_ORG_GNOME_MUTTER_DISPLAY_CONFIG_SKELETON, OrgGnomeMutterDisplayConfigSkeleton))
#define ORG_GNOME_MUTTER_DISPLAY_CONFIG_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), TYPE_ORG_GNOME_MUTTER_DISPLAY_CONFIG_SKELETON, OrgGnomeMutterDisplayConfigSkeletonClass))
#define ORG_GNOME_MUTTER_DISPLAY_CONFIG_SKELETON_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), TYPE_ORG_GNOME_MUTTER_DISPLAY_CONFIG_SKELETON, OrgGnomeMutterDisplayConfigSkeletonClass))
#define IS_ORG_GNOME_MUTTER_DISPLAY_CONFIG_SKELETON(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), TYPE_ORG_GNOME_MUTTER_DISPLAY_CONFIG_SKELETON))
#define IS_ORG_GNOME_MUTTER_DISPLAY_CONFIG_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), TYPE_ORG_GNOME_MUTTER_DISPLAY_CONFIG_SKELETON))

typedef struct _OrgGnomeMutterDisplayConfigSkeleton OrgGnomeMutterDisplayConfigSkeleton;
typedef struct _OrgGnomeMutterDisplayConfigSkeletonClass OrgGnomeMutterDisplayConfigSkeletonClass;
typedef struct _OrgGnomeMutterDisplayConfigSkeletonPrivate OrgGnomeMutterDisplayConfigSkeletonPrivate;

struct _OrgGnomeMutterDisplayConfigSkeleton
{
  /*< private >*/
  GDBusInterfaceSkeleton parent_instance;
  OrgGnomeMutterDisplayConfigSkeletonPrivate *priv;
};

struct _OrgGnomeMutterDisplayConfigSkeletonClass
{
  GDBusInterfaceSkeletonClass parent_class;
};

GType org_gnome_mutter_display_config_skeleton_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (OrgGnomeMutterDisplayConfigSkeleton, g_object_unref)
#endif

OrgGnomeMutterDisplayConfig *org_gnome_mutter_display_config_skeleton_new (void);


/* ------------------------------------------------------------------------ */
/* Declarations for org.gnome.Mutter.InputCapture */

#define TYPE_ORG_GNOME_MUTTER_INPUT_CAPTURE (org_gnome_mutter_input_capture_get_type ())
#define ORG_GNOME_MUTTER_INPUT_CAPTURE(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), TYPE_ORG_GNOME_MUTTER_INPUT_CAPTURE, OrgGnomeMutterInputCapture))
#define IS_ORG_GNOME_MUTTER_INPUT_CAPTURE(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), TYPE_ORG_GNOME_MUTTER_INPUT_CAPTURE))
#define ORG_GNOME_MUTTER_INPUT_CAPTURE_GET_IFACE(o) (G_TYPE_INSTANCE_GET_INTERFACE ((o), TYPE_ORG_GNOME_MUTTER_INPUT_CAPTURE, OrgGnomeMutterInputCaptureIface))

struct _OrgGnomeMutterInputCapture;
typedef struct _OrgGnomeMutterInputCapture OrgGnomeMutterInputCapture;
typedef struct _OrgGnomeMutterInputCaptureIface OrgGnomeMutterInputCaptureIface;

struct _OrgGnomeMutterInputCaptureIface
{
  GTypeInterface parent_iface;


  gboolean (*handle_create_session) (
    OrgGnomeMutterInputCapture *object,
    GDBusMethodInvocation *invocation,
    guint arg_capabilities);

  guint  (*get_supported_capabilities) (OrgGnomeMutterInputCapture *object);

};

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (OrgGnomeMutterInputCapture, g_object_unref)
#endif

GType org_gnome_mutter_input_capture_get_type (void) G_GNUC_CONST;

GDBusInterfaceInfo *org_gnome_mutter_input_capture_interface_info (void);
guint org_gnome_mutter_input_capture_override_properties (GObjectClass *klass, guint property_id_begin);


/* D-Bus method call completion functions: */
void org_gnome_mutter_input_capture_complete_create_session (
    OrgGnomeMutterInputCapture *object,
    GDBusMethodInvocation *invocation,
    const gchar *session_path);



/* D-Bus method calls: */
void org_gnome_mutter_input_capture_call_create_session (
    OrgGnomeMutterInputCapture *proxy,
    guint arg_capabilities,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_mutter_input_capture_call_create_session_finish (
    OrgGnomeMutterInputCapture *proxy,
    gchar ** out_session_path,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_mutter_input_capture_call_create_session_sync (
    OrgGnomeMutterInputCapture *proxy,
    guint arg_capabilities,
    gchar ** out_session_path,
    GCancellable *cancellable,
    GError **error);



/* D-Bus property accessors: */
guint org_gnome_mutter_input_capture_get_supported_capabilities (OrgGnomeMutterInputCapture *object);
void org_gnome_mutter_input_capture_set_supported_capabilities (OrgGnomeMutterInputCapture *object, guint value);


/* ---- */

#define TYPE_ORG_GNOME_MUTTER_INPUT_CAPTURE_PROXY (org_gnome_mutter_input_capture_proxy_get_type ())
#define ORG_GNOME_MUTTER_INPUT_CAPTURE_PROXY(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), TYPE_ORG_GNOME_MUTTER_INPUT_CAPTURE_PROXY, OrgGnomeMutterInputCaptureProxy))
#define ORG_GNOME_MUTTER_INPUT_CAPTURE_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), TYPE_ORG_GNOME_MUTTER_INPUT_CAPTURE_PROXY, OrgGnomeMutterInputCaptureProxyClass))
#define ORG_GNOME_MUTTER_INPUT_CAPTURE_PROXY_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), TYPE_ORG_GNOME_MUTTER_INPUT_CAPTURE_PROXY, OrgGnomeMutterInputCaptureProxyClass))
#define IS_ORG_GNOME_MUTTER_INPUT_CAPTURE_PROXY(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), TYPE_ORG_GNOME_MUTTER_INPUT_CAPTURE_PROXY))
#define IS_ORG_GNOME_MUTTER_INPUT_CAPTURE_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), TYPE_ORG_GNOME_MUTTER_INPUT_CAPTURE_PROXY))

typedef struct _OrgGnomeMutterInputCaptureProxy OrgGnomeMutterInputCaptureProxy;
typedef struct _OrgGnomeMutterInputCaptureProxyClass OrgGnomeMutterInputCaptureProxyClass;
typedef struct _OrgGnomeMutterInputCaptureProxyPrivate OrgGnomeMutterInputCaptureProxyPrivate;

struct _OrgGnomeMutterInputCaptureProxy
{
  /*< private >*/
  GDBusProxy parent_instance;
  OrgGnomeMutterInputCaptureProxyPrivate *priv;
};

struct _OrgGnomeMutterInputCaptureProxyClass
{
  GDBusProxyClass parent_class;
};

GType org_gnome_mutter_input_capture_proxy_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (OrgGnomeMutterInputCaptureProxy, g_object_unref)
#endif

void org_gnome_mutter_input_capture_proxy_new (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
OrgGnomeMutterInputCapture *org_gnome_mutter_input_capture_proxy_new_finish (
    GAsyncResult        *res,
    GError             **error);
OrgGnomeMutterInputCapture *org_gnome_mutter_input_capture_proxy_new_sync (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);

void org_gnome_mutter_input_capture_proxy_new_for_bus (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
OrgGnomeMutterInputCapture *org_gnome_mutter_input_capture_proxy_new_for_bus_finish (
    GAsyncResult        *res,
    GError             **error);
OrgGnomeMutterInputCapture *org_gnome_mutter_input_capture_proxy_new_for_bus_sync (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);


/* ---- */

#define TYPE_ORG_GNOME_MUTTER_INPUT_CAPTURE_SKELETON (org_gnome_mutter_input_capture_skeleton_get_type ())
#define ORG_GNOME_MUTTER_INPUT_CAPTURE_SKELETON(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), TYPE_ORG_GNOME_MUTTER_INPUT_CAPTURE_SKELETON, OrgGnomeMutterInputCaptureSkeleton))
#define ORG_GNOME_MUTTER_INPUT_CAPTURE_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), TYPE_ORG_GNOME_MUTTER_INPUT_CAPTURE_SKELETON, OrgGnomeMutterInputCaptureSkeletonClass))
#define ORG_GNOME_MUTTER_INPUT_CAPTURE_SKELETON_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), TYPE_ORG_GNOME_MUTTER_INPUT_CAPTURE_SKELETON, OrgGnomeMutterInputCaptureSkeletonClass))
#define IS_ORG_GNOME_MUTTER_INPUT_CAPTURE_SKELETON(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), TYPE_ORG_GNOME_MUTTER_INPUT_CAPTURE_SKELETON))
#define IS_ORG_GNOME_MUTTER_INPUT_CAPTURE_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), TYPE_ORG_GNOME_MUTTER_INPUT_CAPTURE_SKELETON))

typedef struct _OrgGnomeMutterInputCaptureSkeleton OrgGnomeMutterInputCaptureSkeleton;
typedef struct _OrgGnomeMutterInputCaptureSkeletonClass OrgGnomeMutterInputCaptureSkeletonClass;
typedef struct _OrgGnomeMutterInputCaptureSkeletonPrivate OrgGnomeMutterInputCaptureSkeletonPrivate;

struct _OrgGnomeMutterInputCaptureSkeleton
{
  /*< private >*/
  GDBusInterfaceSkeleton parent_instance;
  OrgGnomeMutterInputCaptureSkeletonPrivate *priv;
};

struct _OrgGnomeMutterInputCaptureSkeletonClass
{
  GDBusInterfaceSkeletonClass parent_class;
};

GType org_gnome_mutter_input_capture_skeleton_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (OrgGnomeMutterInputCaptureSkeleton, g_object_unref)
#endif

OrgGnomeMutterInputCapture *org_gnome_mutter_input_capture_skeleton_new (void);


/* ------------------------------------------------------------------------ */
/* Declarations for org.gnome.Mutter.InputCapture.Session */

#define TYPE_ORG_GNOME_MUTTER_INPUT_CAPTURE_SESSION (org_gnome_mutter_input_capture_session_get_type ())
#define ORG_GNOME_MUTTER_INPUT_CAPTURE_SESSION(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), TYPE_ORG_GNOME_MUTTER_INPUT_CAPTURE_SESSION, OrgGnomeMutterInputCaptureSession))
#define IS_ORG_GNOME_MUTTER_INPUT_CAPTURE_SESSION(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), TYPE_ORG_GNOME_MUTTER_INPUT_CAPTURE_SESSION))
#define ORG_GNOME_MUTTER_INPUT_CAPTURE_SESSION_GET_IFACE(o) (G_TYPE_INSTANCE_GET_INTERFACE ((o), TYPE_ORG_GNOME_MUTTER_INPUT_CAPTURE_SESSION, OrgGnomeMutterInputCaptureSessionIface))

struct _OrgGnomeMutterInputCaptureSession;
typedef struct _OrgGnomeMutterInputCaptureSession OrgGnomeMutterInputCaptureSession;
typedef struct _OrgGnomeMutterInputCaptureSessionIface OrgGnomeMutterInputCaptureSessionIface;

struct _OrgGnomeMutterInputCaptureSessionIface
{
  GTypeInterface parent_iface;


  gboolean (*handle_add_barrier) (
    OrgGnomeMutterInputCaptureSession *object,
    GDBusMethodInvocation *invocation,
    guint arg_serial,
    GVariant *arg_position);

  gboolean (*handle_clear_barriers) (
    OrgGnomeMutterInputCaptureSession *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_close) (
    OrgGnomeMutterInputCaptureSession *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_connect_to_eis) (
    OrgGnomeMutterInputCaptureSession *object,
    GDBusMethodInvocation *invocation,
    GUnixFDList *fd_list);

  gboolean (*handle_disable) (
    OrgGnomeMutterInputCaptureSession *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_enable) (
    OrgGnomeMutterInputCaptureSession *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_get_zones) (
    OrgGnomeMutterInputCaptureSession *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_release) (
    OrgGnomeMutterInputCaptureSession *object,
    GDBusMethodInvocation *invocation,
    GVariant *arg_options);

  void (*activated) (
    OrgGnomeMutterInputCaptureSession *object,
    guint arg_barrier_id,
    guint arg_activation_id,
    GVariant *arg_cursor_position);

  void (*closed) (
    OrgGnomeMutterInputCaptureSession *object);

  void (*deactivated) (
    OrgGnomeMutterInputCaptureSession *object,
    guint arg_activation_id);

  void (*disabled) (
    OrgGnomeMutterInputCaptureSession *object);

  void (*zones_changed) (
    OrgGnomeMutterInputCaptureSession *object);

};

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (OrgGnomeMutterInputCaptureSession, g_object_unref)
#endif

GType org_gnome_mutter_input_capture_session_get_type (void) G_GNUC_CONST;

GDBusInterfaceInfo *org_gnome_mutter_input_capture_session_interface_info (void);
guint org_gnome_mutter_input_capture_session_override_properties (GObjectClass *klass, guint property_id_begin);


/* D-Bus method call completion functions: */
void org_gnome_mutter_input_capture_session_complete_get_zones (
    OrgGnomeMutterInputCaptureSession *object,
    GDBusMethodInvocation *invocation,
    guint serial,
    GVariant *zones);

void org_gnome_mutter_input_capture_session_complete_add_barrier (
    OrgGnomeMutterInputCaptureSession *object,
    GDBusMethodInvocation *invocation,
    guint id);

void org_gnome_mutter_input_capture_session_complete_clear_barriers (
    OrgGnomeMutterInputCaptureSession *object,
    GDBusMethodInvocation *invocation);

void org_gnome_mutter_input_capture_session_complete_enable (
    OrgGnomeMutterInputCaptureSession *object,
    GDBusMethodInvocation *invocation);

void org_gnome_mutter_input_capture_session_complete_disable (
    OrgGnomeMutterInputCaptureSession *object,
    GDBusMethodInvocation *invocation);

void org_gnome_mutter_input_capture_session_complete_connect_to_eis (
    OrgGnomeMutterInputCaptureSession *object,
    GDBusMethodInvocation *invocation,
    GUnixFDList *fd_list,
    GVariant *fd);

void org_gnome_mutter_input_capture_session_complete_release (
    OrgGnomeMutterInputCaptureSession *object,
    GDBusMethodInvocation *invocation);

void org_gnome_mutter_input_capture_session_complete_close (
    OrgGnomeMutterInputCaptureSession *object,
    GDBusMethodInvocation *invocation);



/* D-Bus signal emissions functions: */
void org_gnome_mutter_input_capture_session_emit_activated (
    OrgGnomeMutterInputCaptureSession *object,
    guint arg_barrier_id,
    guint arg_activation_id,
    GVariant *arg_cursor_position);

void org_gnome_mutter_input_capture_session_emit_deactivated (
    OrgGnomeMutterInputCaptureSession *object,
    guint arg_activation_id);

void org_gnome_mutter_input_capture_session_emit_zones_changed (
    OrgGnomeMutterInputCaptureSession *object);

void org_gnome_mutter_input_capture_session_emit_disabled (
    OrgGnomeMutterInputCaptureSession *object);

void org_gnome_mutter_input_capture_session_emit_closed (
    OrgGnomeMutterInputCaptureSession *object);



/* D-Bus method calls: */
void org_gnome_mutter_input_capture_session_call_get_zones (
    OrgGnomeMutterInputCaptureSession *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_mutter_input_capture_session_call_get_zones_finish (
    OrgGnomeMutterInputCaptureSession *proxy,
    guint* out_serial,
    GVariant ** out_zones,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_mutter_input_capture_session_call_get_zones_sync (
    OrgGnomeMutterInputCaptureSession *proxy,
    guint* out_serial,
    GVariant ** out_zones,
    GCancellable *cancellable,
    GError **error);

void org_gnome_mutter_input_capture_session_call_add_barrier (
    OrgGnomeMutterInputCaptureSession *proxy,
    guint arg_serial,
    GVariant *arg_position,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_mutter_input_capture_session_call_add_barrier_finish (
    OrgGnomeMutterInputCaptureSession *proxy,
    guint* out_id,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_mutter_input_capture_session_call_add_barrier_sync (
    OrgGnomeMutterInputCaptureSession *proxy,
    guint arg_serial,
    GVariant *arg_position,
    guint* out_id,
    GCancellable *cancellable,
    GError **error);

void org_gnome_mutter_input_capture_session_call_clear_barriers (
    OrgGnomeMutterInputCaptureSession *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_mutter_input_capture_session_call_clear_barriers_finish (
    OrgGnomeMutterInputCaptureSession *proxy,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_mutter_input_capture_session_call_clear_barriers_sync (
    OrgGnomeMutterInputCaptureSession *proxy,
    GCancellable *cancellable,
    GError **error);

void org_gnome_mutter_input_capture_session_call_enable (
    OrgGnomeMutterInputCaptureSession *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_mutter_input_capture_session_call_enable_finish (
    OrgGnomeMutterInputCaptureSession *proxy,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_mutter_input_capture_session_call_enable_sync (
    OrgGnomeMutterInputCaptureSession *proxy,
    GCancellable *cancellable,
    GError **error);

void org_gnome_mutter_input_capture_session_call_disable (
    OrgGnomeMutterInputCaptureSession *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_mutter_input_capture_session_call_disable_finish (
    OrgGnomeMutterInputCaptureSession *proxy,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_mutter_input_capture_session_call_disable_sync (
    OrgGnomeMutterInputCaptureSession *proxy,
    GCancellable *cancellable,
    GError **error);

void org_gnome_mutter_input_capture_session_call_connect_to_eis (
    OrgGnomeMutterInputCaptureSession *proxy,
    GUnixFDList *fd_list,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_mutter_input_capture_session_call_connect_to_eis_finish (
    OrgGnomeMutterInputCaptureSession *proxy,
    GVariant ** out_fd,
    GUnixFDList **out_fd_list,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_mutter_input_capture_session_call_connect_to_eis_sync (
    OrgGnomeMutterInputCaptureSession *proxy,
    GUnixFDList  *fd_list,
    GVariant ** out_fd,
    GUnixFDList **out_fd_list,
    GCancellable *cancellable,
    GError **error);

void org_gnome_mutter_input_capture_session_call_release (
    OrgGnomeMutterInputCaptureSession *proxy,
    GVariant *arg_options,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_mutter_input_capture_session_call_release_finish (
    OrgGnomeMutterInputCaptureSession *proxy,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_mutter_input_capture_session_call_release_sync (
    OrgGnomeMutterInputCaptureSession *proxy,
    GVariant *arg_options,
    GCancellable *cancellable,
    GError **error);

void org_gnome_mutter_input_capture_session_call_close (
    OrgGnomeMutterInputCaptureSession *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_mutter_input_capture_session_call_close_finish (
    OrgGnomeMutterInputCaptureSession *proxy,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_mutter_input_capture_session_call_close_sync (
    OrgGnomeMutterInputCaptureSession *proxy,
    GCancellable *cancellable,
    GError **error);



/* ---- */

#define TYPE_ORG_GNOME_MUTTER_INPUT_CAPTURE_SESSION_PROXY (org_gnome_mutter_input_capture_session_proxy_get_type ())
#define ORG_GNOME_MUTTER_INPUT_CAPTURE_SESSION_PROXY(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), TYPE_ORG_GNOME_MUTTER_INPUT_CAPTURE_SESSION_PROXY, OrgGnomeMutterInputCaptureSessionProxy))
#define ORG_GNOME_MUTTER_INPUT_CAPTURE_SESSION_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), TYPE_ORG_GNOME_MUTTER_INPUT_CAPTURE_SESSION_PROXY, OrgGnomeMutterInputCaptureSessionProxyClass))
#define ORG_GNOME_MUTTER_INPUT_CAPTURE_SESSION_PROXY_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), TYPE_ORG_GNOME_MUTTER_INPUT_CAPTURE_SESSION_PROXY, OrgGnomeMutterInputCaptureSessionProxyClass))
#define IS_ORG_GNOME_MUTTER_INPUT_CAPTURE_SESSION_PROXY(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), TYPE_ORG_GNOME_MUTTER_INPUT_CAPTURE_SESSION_PROXY))
#define IS_ORG_GNOME_MUTTER_INPUT_CAPTURE_SESSION_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), TYPE_ORG_GNOME_MUTTER_INPUT_CAPTURE_SESSION_PROXY))

typedef struct _OrgGnomeMutterInputCaptureSessionProxy OrgGnomeMutterInputCaptureSessionProxy;
typedef struct _OrgGnomeMutterInputCaptureSessionProxyClass OrgGnomeMutterInputCaptureSessionProxyClass;
typedef struct _OrgGnomeMutterInputCaptureSessionProxyPrivate OrgGnomeMutterInputCaptureSessionProxyPrivate;

struct _OrgGnomeMutterInputCaptureSessionProxy
{
  /*< private >*/
  GDBusProxy parent_instance;
  OrgGnomeMutterInputCaptureSessionProxyPrivate *priv;
};

struct _OrgGnomeMutterInputCaptureSessionProxyClass
{
  GDBusProxyClass parent_class;
};

GType org_gnome_mutter_input_capture_session_proxy_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (OrgGnomeMutterInputCaptureSessionProxy, g_object_unref)
#endif

void org_gnome_mutter_input_capture_session_proxy_new (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
OrgGnomeMutterInputCaptureSession *org_gnome_mutter_input_capture_session_proxy_new_finish (
    GAsyncResult        *res,
    GError             **error);
OrgGnomeMutterInputCaptureSession *org_gnome_mutter_input_capture_session_proxy_new_sync (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);

void org_gnome_mutter_input_capture_session_proxy_new_for_bus (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
OrgGnomeMutterInputCaptureSession *org_gnome_mutter_input_capture_session_proxy_new_for_bus_finish (
    GAsyncResult        *res,
    GError             **error);
OrgGnomeMutterInputCaptureSession *org_gnome_mutter_input_capture_session_proxy_new_for_bus_sync (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);


/* ---- */

#define TYPE_ORG_GNOME_MUTTER_INPUT_CAPTURE_SESSION_SKELETON (org_gnome_mutter_input_capture_session_skeleton_get_type ())
#define ORG_GNOME_MUTTER_INPUT_CAPTURE_SESSION_SKELETON(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), TYPE_ORG_GNOME_MUTTER_INPUT_CAPTURE_SESSION_SKELETON, OrgGnomeMutterInputCaptureSessionSkeleton))
#define ORG_GNOME_MUTTER_INPUT_CAPTURE_SESSION_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), TYPE_ORG_GNOME_MUTTER_INPUT_CAPTURE_SESSION_SKELETON, OrgGnomeMutterInputCaptureSessionSkeletonClass))
#define ORG_GNOME_MUTTER_INPUT_CAPTURE_SESSION_SKELETON_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), TYPE_ORG_GNOME_MUTTER_INPUT_CAPTURE_SESSION_SKELETON, OrgGnomeMutterInputCaptureSessionSkeletonClass))
#define IS_ORG_GNOME_MUTTER_INPUT_CAPTURE_SESSION_SKELETON(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), TYPE_ORG_GNOME_MUTTER_INPUT_CAPTURE_SESSION_SKELETON))
#define IS_ORG_GNOME_MUTTER_INPUT_CAPTURE_SESSION_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), TYPE_ORG_GNOME_MUTTER_INPUT_CAPTURE_SESSION_SKELETON))

typedef struct _OrgGnomeMutterInputCaptureSessionSkeleton OrgGnomeMutterInputCaptureSessionSkeleton;
typedef struct _OrgGnomeMutterInputCaptureSessionSkeletonClass OrgGnomeMutterInputCaptureSessionSkeletonClass;
typedef struct _OrgGnomeMutterInputCaptureSessionSkeletonPrivate OrgGnomeMutterInputCaptureSessionSkeletonPrivate;

struct _OrgGnomeMutterInputCaptureSessionSkeleton
{
  /*< private >*/
  GDBusInterfaceSkeleton parent_instance;
  OrgGnomeMutterInputCaptureSessionSkeletonPrivate *priv;
};

struct _OrgGnomeMutterInputCaptureSessionSkeletonClass
{
  GDBusInterfaceSkeletonClass parent_class;
};

GType org_gnome_mutter_input_capture_session_skeleton_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (OrgGnomeMutterInputCaptureSessionSkeleton, g_object_unref)
#endif

OrgGnomeMutterInputCaptureSession *org_gnome_mutter_input_capture_session_skeleton_new (void);


/* ------------------------------------------------------------------------ */
/* Declarations for org.gnome.Mutter.RemoteDesktop */

#define TYPE_ORG_GNOME_MUTTER_REMOTE_DESKTOP (org_gnome_mutter_remote_desktop_get_type ())
#define ORG_GNOME_MUTTER_REMOTE_DESKTOP(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), TYPE_ORG_GNOME_MUTTER_REMOTE_DESKTOP, OrgGnomeMutterRemoteDesktop))
#define IS_ORG_GNOME_MUTTER_REMOTE_DESKTOP(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), TYPE_ORG_GNOME_MUTTER_REMOTE_DESKTOP))
#define ORG_GNOME_MUTTER_REMOTE_DESKTOP_GET_IFACE(o) (G_TYPE_INSTANCE_GET_INTERFACE ((o), TYPE_ORG_GNOME_MUTTER_REMOTE_DESKTOP, OrgGnomeMutterRemoteDesktopIface))

struct _OrgGnomeMutterRemoteDesktop;
typedef struct _OrgGnomeMutterRemoteDesktop OrgGnomeMutterRemoteDesktop;
typedef struct _OrgGnomeMutterRemoteDesktopIface OrgGnomeMutterRemoteDesktopIface;

struct _OrgGnomeMutterRemoteDesktopIface
{
  GTypeInterface parent_iface;


  gboolean (*handle_create_session) (
    OrgGnomeMutterRemoteDesktop *object,
    GDBusMethodInvocation *invocation);

  guint  (*get_supported_device_types) (OrgGnomeMutterRemoteDesktop *object);

  gint  (*get_version) (OrgGnomeMutterRemoteDesktop *object);

};

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (OrgGnomeMutterRemoteDesktop, g_object_unref)
#endif

GType org_gnome_mutter_remote_desktop_get_type (void) G_GNUC_CONST;

GDBusInterfaceInfo *org_gnome_mutter_remote_desktop_interface_info (void);
guint org_gnome_mutter_remote_desktop_override_properties (GObjectClass *klass, guint property_id_begin);


/* D-Bus method call completion functions: */
void org_gnome_mutter_remote_desktop_complete_create_session (
    OrgGnomeMutterRemoteDesktop *object,
    GDBusMethodInvocation *invocation,
    const gchar *session_path);



/* D-Bus method calls: */
void org_gnome_mutter_remote_desktop_call_create_session (
    OrgGnomeMutterRemoteDesktop *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_mutter_remote_desktop_call_create_session_finish (
    OrgGnomeMutterRemoteDesktop *proxy,
    gchar ** out_session_path,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_mutter_remote_desktop_call_create_session_sync (
    OrgGnomeMutterRemoteDesktop *proxy,
    gchar ** out_session_path,
    GCancellable *cancellable,
    GError **error);



/* D-Bus property accessors: */
guint org_gnome_mutter_remote_desktop_get_supported_device_types (OrgGnomeMutterRemoteDesktop *object);
void org_gnome_mutter_remote_desktop_set_supported_device_types (OrgGnomeMutterRemoteDesktop *object, guint value);

gint org_gnome_mutter_remote_desktop_get_version (OrgGnomeMutterRemoteDesktop *object);
void org_gnome_mutter_remote_desktop_set_version (OrgGnomeMutterRemoteDesktop *object, gint value);


/* ---- */

#define TYPE_ORG_GNOME_MUTTER_REMOTE_DESKTOP_PROXY (org_gnome_mutter_remote_desktop_proxy_get_type ())
#define ORG_GNOME_MUTTER_REMOTE_DESKTOP_PROXY(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), TYPE_ORG_GNOME_MUTTER_REMOTE_DESKTOP_PROXY, OrgGnomeMutterRemoteDesktopProxy))
#define ORG_GNOME_MUTTER_REMOTE_DESKTOP_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), TYPE_ORG_GNOME_MUTTER_REMOTE_DESKTOP_PROXY, OrgGnomeMutterRemoteDesktopProxyClass))
#define ORG_GNOME_MUTTER_REMOTE_DESKTOP_PROXY_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), TYPE_ORG_GNOME_MUTTER_REMOTE_DESKTOP_PROXY, OrgGnomeMutterRemoteDesktopProxyClass))
#define IS_ORG_GNOME_MUTTER_REMOTE_DESKTOP_PROXY(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), TYPE_ORG_GNOME_MUTTER_REMOTE_DESKTOP_PROXY))
#define IS_ORG_GNOME_MUTTER_REMOTE_DESKTOP_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), TYPE_ORG_GNOME_MUTTER_REMOTE_DESKTOP_PROXY))

typedef struct _OrgGnomeMutterRemoteDesktopProxy OrgGnomeMutterRemoteDesktopProxy;
typedef struct _OrgGnomeMutterRemoteDesktopProxyClass OrgGnomeMutterRemoteDesktopProxyClass;
typedef struct _OrgGnomeMutterRemoteDesktopProxyPrivate OrgGnomeMutterRemoteDesktopProxyPrivate;

struct _OrgGnomeMutterRemoteDesktopProxy
{
  /*< private >*/
  GDBusProxy parent_instance;
  OrgGnomeMutterRemoteDesktopProxyPrivate *priv;
};

struct _OrgGnomeMutterRemoteDesktopProxyClass
{
  GDBusProxyClass parent_class;
};

GType org_gnome_mutter_remote_desktop_proxy_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (OrgGnomeMutterRemoteDesktopProxy, g_object_unref)
#endif

void org_gnome_mutter_remote_desktop_proxy_new (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
OrgGnomeMutterRemoteDesktop *org_gnome_mutter_remote_desktop_proxy_new_finish (
    GAsyncResult        *res,
    GError             **error);
OrgGnomeMutterRemoteDesktop *org_gnome_mutter_remote_desktop_proxy_new_sync (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);

void org_gnome_mutter_remote_desktop_proxy_new_for_bus (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
OrgGnomeMutterRemoteDesktop *org_gnome_mutter_remote_desktop_proxy_new_for_bus_finish (
    GAsyncResult        *res,
    GError             **error);
OrgGnomeMutterRemoteDesktop *org_gnome_mutter_remote_desktop_proxy_new_for_bus_sync (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);


/* ---- */

#define TYPE_ORG_GNOME_MUTTER_REMOTE_DESKTOP_SKELETON (org_gnome_mutter_remote_desktop_skeleton_get_type ())
#define ORG_GNOME_MUTTER_REMOTE_DESKTOP_SKELETON(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), TYPE_ORG_GNOME_MUTTER_REMOTE_DESKTOP_SKELETON, OrgGnomeMutterRemoteDesktopSkeleton))
#define ORG_GNOME_MUTTER_REMOTE_DESKTOP_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), TYPE_ORG_GNOME_MUTTER_REMOTE_DESKTOP_SKELETON, OrgGnomeMutterRemoteDesktopSkeletonClass))
#define ORG_GNOME_MUTTER_REMOTE_DESKTOP_SKELETON_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), TYPE_ORG_GNOME_MUTTER_REMOTE_DESKTOP_SKELETON, OrgGnomeMutterRemoteDesktopSkeletonClass))
#define IS_ORG_GNOME_MUTTER_REMOTE_DESKTOP_SKELETON(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), TYPE_ORG_GNOME_MUTTER_REMOTE_DESKTOP_SKELETON))
#define IS_ORG_GNOME_MUTTER_REMOTE_DESKTOP_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), TYPE_ORG_GNOME_MUTTER_REMOTE_DESKTOP_SKELETON))

typedef struct _OrgGnomeMutterRemoteDesktopSkeleton OrgGnomeMutterRemoteDesktopSkeleton;
typedef struct _OrgGnomeMutterRemoteDesktopSkeletonClass OrgGnomeMutterRemoteDesktopSkeletonClass;
typedef struct _OrgGnomeMutterRemoteDesktopSkeletonPrivate OrgGnomeMutterRemoteDesktopSkeletonPrivate;

struct _OrgGnomeMutterRemoteDesktopSkeleton
{
  /*< private >*/
  GDBusInterfaceSkeleton parent_instance;
  OrgGnomeMutterRemoteDesktopSkeletonPrivate *priv;
};

struct _OrgGnomeMutterRemoteDesktopSkeletonClass
{
  GDBusInterfaceSkeletonClass parent_class;
};

GType org_gnome_mutter_remote_desktop_skeleton_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (OrgGnomeMutterRemoteDesktopSkeleton, g_object_unref)
#endif

OrgGnomeMutterRemoteDesktop *org_gnome_mutter_remote_desktop_skeleton_new (void);


/* ------------------------------------------------------------------------ */
/* Declarations for org.gnome.Mutter.RemoteDesktop.Session */

#define TYPE_ORG_GNOME_MUTTER_REMOTE_DESKTOP_SESSION (org_gnome_mutter_remote_desktop_session_get_type ())
#define ORG_GNOME_MUTTER_REMOTE_DESKTOP_SESSION(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), TYPE_ORG_GNOME_MUTTER_REMOTE_DESKTOP_SESSION, OrgGnomeMutterRemoteDesktopSession))
#define IS_ORG_GNOME_MUTTER_REMOTE_DESKTOP_SESSION(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), TYPE_ORG_GNOME_MUTTER_REMOTE_DESKTOP_SESSION))
#define ORG_GNOME_MUTTER_REMOTE_DESKTOP_SESSION_GET_IFACE(o) (G_TYPE_INSTANCE_GET_INTERFACE ((o), TYPE_ORG_GNOME_MUTTER_REMOTE_DESKTOP_SESSION, OrgGnomeMutterRemoteDesktopSessionIface))

struct _OrgGnomeMutterRemoteDesktopSession;
typedef struct _OrgGnomeMutterRemoteDesktopSession OrgGnomeMutterRemoteDesktopSession;
typedef struct _OrgGnomeMutterRemoteDesktopSessionIface OrgGnomeMutterRemoteDesktopSessionIface;

struct _OrgGnomeMutterRemoteDesktopSessionIface
{
  GTypeInterface parent_iface;



  gboolean (*handle_connect_to_eis) (
    OrgGnomeMutterRemoteDesktopSession *object,
    GDBusMethodInvocation *invocation,
    GUnixFDList *fd_list,
    GVariant *arg_options);

  gboolean (*handle_disable_clipboard) (
    OrgGnomeMutterRemoteDesktopSession *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_enable_clipboard) (
    OrgGnomeMutterRemoteDesktopSession *object,
    GDBusMethodInvocation *invocation,
    GVariant *arg_options);

  gboolean (*handle_notify_keyboard_keycode) (
    OrgGnomeMutterRemoteDesktopSession *object,
    GDBusMethodInvocation *invocation,
    guint arg_keycode,
    gboolean arg_state);

  gboolean (*handle_notify_keyboard_keysym) (
    OrgGnomeMutterRemoteDesktopSession *object,
    GDBusMethodInvocation *invocation,
    guint arg_keysym,
    gboolean arg_state);

  gboolean (*handle_notify_pointer_axis) (
    OrgGnomeMutterRemoteDesktopSession *object,
    GDBusMethodInvocation *invocation,
    gdouble arg_dx,
    gdouble arg_dy,
    guint arg_flags);

  gboolean (*handle_notify_pointer_axis_discrete) (
    OrgGnomeMutterRemoteDesktopSession *object,
    GDBusMethodInvocation *invocation,
    guint arg_axis,
    gint arg_steps);

  gboolean (*handle_notify_pointer_button) (
    OrgGnomeMutterRemoteDesktopSession *object,
    GDBusMethodInvocation *invocation,
    gint arg_button,
    gboolean arg_state);

  gboolean (*handle_notify_pointer_motion_absolute) (
    OrgGnomeMutterRemoteDesktopSession *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_stream,
    gdouble arg_x,
    gdouble arg_y);

  gboolean (*handle_notify_pointer_motion_relative) (
    OrgGnomeMutterRemoteDesktopSession *object,
    GDBusMethodInvocation *invocation,
    gdouble arg_dx,
    gdouble arg_dy);

  gboolean (*handle_notify_touch_down) (
    OrgGnomeMutterRemoteDesktopSession *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_stream,
    guint arg_slot,
    gdouble arg_x,
    gdouble arg_y);

  gboolean (*handle_notify_touch_motion) (
    OrgGnomeMutterRemoteDesktopSession *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_stream,
    guint arg_slot,
    gdouble arg_x,
    gdouble arg_y);

  gboolean (*handle_notify_touch_up) (
    OrgGnomeMutterRemoteDesktopSession *object,
    GDBusMethodInvocation *invocation,
    guint arg_slot);

  gboolean (*handle_selection_read) (
    OrgGnomeMutterRemoteDesktopSession *object,
    GDBusMethodInvocation *invocation,
    GUnixFDList *fd_list,
    const gchar *arg_mime_type);

  gboolean (*handle_selection_write) (
    OrgGnomeMutterRemoteDesktopSession *object,
    GDBusMethodInvocation *invocation,
    GUnixFDList *fd_list,
    guint arg_serial);

  gboolean (*handle_selection_write_done) (
    OrgGnomeMutterRemoteDesktopSession *object,
    GDBusMethodInvocation *invocation,
    guint arg_serial,
    gboolean arg_success);

  gboolean (*handle_set_selection) (
    OrgGnomeMutterRemoteDesktopSession *object,
    GDBusMethodInvocation *invocation,
    GVariant *arg_options);

  gboolean (*handle_start) (
    OrgGnomeMutterRemoteDesktopSession *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_stop) (
    OrgGnomeMutterRemoteDesktopSession *object,
    GDBusMethodInvocation *invocation);

  gboolean  (*get_caps_lock_state) (OrgGnomeMutterRemoteDesktopSession *object);

  gboolean  (*get_num_lock_state) (OrgGnomeMutterRemoteDesktopSession *object);

  const gchar * (*get_session_id) (OrgGnomeMutterRemoteDesktopSession *object);

  void (*closed) (
    OrgGnomeMutterRemoteDesktopSession *object);

  void (*selection_owner_changed) (
    OrgGnomeMutterRemoteDesktopSession *object,
    GVariant *arg_options);

  void (*selection_transfer) (
    OrgGnomeMutterRemoteDesktopSession *object,
    const gchar *arg_mime_type,
    guint arg_serial);

};

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (OrgGnomeMutterRemoteDesktopSession, g_object_unref)
#endif

GType org_gnome_mutter_remote_desktop_session_get_type (void) G_GNUC_CONST;

GDBusInterfaceInfo *org_gnome_mutter_remote_desktop_session_interface_info (void);
guint org_gnome_mutter_remote_desktop_session_override_properties (GObjectClass *klass, guint property_id_begin);


/* D-Bus method call completion functions: */
void org_gnome_mutter_remote_desktop_session_complete_start (
    OrgGnomeMutterRemoteDesktopSession *object,
    GDBusMethodInvocation *invocation);

void org_gnome_mutter_remote_desktop_session_complete_stop (
    OrgGnomeMutterRemoteDesktopSession *object,
    GDBusMethodInvocation *invocation);

void org_gnome_mutter_remote_desktop_session_complete_notify_keyboard_keycode (
    OrgGnomeMutterRemoteDesktopSession *object,
    GDBusMethodInvocation *invocation);

void org_gnome_mutter_remote_desktop_session_complete_notify_keyboard_keysym (
    OrgGnomeMutterRemoteDesktopSession *object,
    GDBusMethodInvocation *invocation);

void org_gnome_mutter_remote_desktop_session_complete_notify_pointer_button (
    OrgGnomeMutterRemoteDesktopSession *object,
    GDBusMethodInvocation *invocation);

void org_gnome_mutter_remote_desktop_session_complete_notify_pointer_axis (
    OrgGnomeMutterRemoteDesktopSession *object,
    GDBusMethodInvocation *invocation);

void org_gnome_mutter_remote_desktop_session_complete_notify_pointer_axis_discrete (
    OrgGnomeMutterRemoteDesktopSession *object,
    GDBusMethodInvocation *invocation);

void org_gnome_mutter_remote_desktop_session_complete_notify_pointer_motion_relative (
    OrgGnomeMutterRemoteDesktopSession *object,
    GDBusMethodInvocation *invocation);

void org_gnome_mutter_remote_desktop_session_complete_notify_pointer_motion_absolute (
    OrgGnomeMutterRemoteDesktopSession *object,
    GDBusMethodInvocation *invocation);

void org_gnome_mutter_remote_desktop_session_complete_notify_touch_down (
    OrgGnomeMutterRemoteDesktopSession *object,
    GDBusMethodInvocation *invocation);

void org_gnome_mutter_remote_desktop_session_complete_notify_touch_motion (
    OrgGnomeMutterRemoteDesktopSession *object,
    GDBusMethodInvocation *invocation);

void org_gnome_mutter_remote_desktop_session_complete_notify_touch_up (
    OrgGnomeMutterRemoteDesktopSession *object,
    GDBusMethodInvocation *invocation);

void org_gnome_mutter_remote_desktop_session_complete_enable_clipboard (
    OrgGnomeMutterRemoteDesktopSession *object,
    GDBusMethodInvocation *invocation);

void org_gnome_mutter_remote_desktop_session_complete_disable_clipboard (
    OrgGnomeMutterRemoteDesktopSession *object,
    GDBusMethodInvocation *invocation);

void org_gnome_mutter_remote_desktop_session_complete_set_selection (
    OrgGnomeMutterRemoteDesktopSession *object,
    GDBusMethodInvocation *invocation);

void org_gnome_mutter_remote_desktop_session_complete_selection_write (
    OrgGnomeMutterRemoteDesktopSession *object,
    GDBusMethodInvocation *invocation,
    GUnixFDList *fd_list,
    GVariant *fd);

void org_gnome_mutter_remote_desktop_session_complete_selection_write_done (
    OrgGnomeMutterRemoteDesktopSession *object,
    GDBusMethodInvocation *invocation);

void org_gnome_mutter_remote_desktop_session_complete_selection_read (
    OrgGnomeMutterRemoteDesktopSession *object,
    GDBusMethodInvocation *invocation,
    GUnixFDList *fd_list,
    GVariant *fd);

void org_gnome_mutter_remote_desktop_session_complete_connect_to_eis (
    OrgGnomeMutterRemoteDesktopSession *object,
    GDBusMethodInvocation *invocation,
    GUnixFDList *fd_list,
    GVariant *fd);



/* D-Bus signal emissions functions: */
void org_gnome_mutter_remote_desktop_session_emit_closed (
    OrgGnomeMutterRemoteDesktopSession *object);

void org_gnome_mutter_remote_desktop_session_emit_selection_owner_changed (
    OrgGnomeMutterRemoteDesktopSession *object,
    GVariant *arg_options);

void org_gnome_mutter_remote_desktop_session_emit_selection_transfer (
    OrgGnomeMutterRemoteDesktopSession *object,
    const gchar *arg_mime_type,
    guint arg_serial);



/* D-Bus method calls: */
void org_gnome_mutter_remote_desktop_session_call_start (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_mutter_remote_desktop_session_call_start_finish (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_mutter_remote_desktop_session_call_start_sync (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    GCancellable *cancellable,
    GError **error);

void org_gnome_mutter_remote_desktop_session_call_stop (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_mutter_remote_desktop_session_call_stop_finish (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_mutter_remote_desktop_session_call_stop_sync (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    GCancellable *cancellable,
    GError **error);

void org_gnome_mutter_remote_desktop_session_call_notify_keyboard_keycode (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    guint arg_keycode,
    gboolean arg_state,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_mutter_remote_desktop_session_call_notify_keyboard_keycode_finish (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_mutter_remote_desktop_session_call_notify_keyboard_keycode_sync (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    guint arg_keycode,
    gboolean arg_state,
    GCancellable *cancellable,
    GError **error);

void org_gnome_mutter_remote_desktop_session_call_notify_keyboard_keysym (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    guint arg_keysym,
    gboolean arg_state,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_mutter_remote_desktop_session_call_notify_keyboard_keysym_finish (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_mutter_remote_desktop_session_call_notify_keyboard_keysym_sync (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    guint arg_keysym,
    gboolean arg_state,
    GCancellable *cancellable,
    GError **error);

void org_gnome_mutter_remote_desktop_session_call_notify_pointer_button (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    gint arg_button,
    gboolean arg_state,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_mutter_remote_desktop_session_call_notify_pointer_button_finish (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_mutter_remote_desktop_session_call_notify_pointer_button_sync (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    gint arg_button,
    gboolean arg_state,
    GCancellable *cancellable,
    GError **error);

void org_gnome_mutter_remote_desktop_session_call_notify_pointer_axis (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    gdouble arg_dx,
    gdouble arg_dy,
    guint arg_flags,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_mutter_remote_desktop_session_call_notify_pointer_axis_finish (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_mutter_remote_desktop_session_call_notify_pointer_axis_sync (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    gdouble arg_dx,
    gdouble arg_dy,
    guint arg_flags,
    GCancellable *cancellable,
    GError **error);

void org_gnome_mutter_remote_desktop_session_call_notify_pointer_axis_discrete (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    guint arg_axis,
    gint arg_steps,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_mutter_remote_desktop_session_call_notify_pointer_axis_discrete_finish (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_mutter_remote_desktop_session_call_notify_pointer_axis_discrete_sync (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    guint arg_axis,
    gint arg_steps,
    GCancellable *cancellable,
    GError **error);

void org_gnome_mutter_remote_desktop_session_call_notify_pointer_motion_relative (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    gdouble arg_dx,
    gdouble arg_dy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_mutter_remote_desktop_session_call_notify_pointer_motion_relative_finish (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_mutter_remote_desktop_session_call_notify_pointer_motion_relative_sync (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    gdouble arg_dx,
    gdouble arg_dy,
    GCancellable *cancellable,
    GError **error);

void org_gnome_mutter_remote_desktop_session_call_notify_pointer_motion_absolute (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    const gchar *arg_stream,
    gdouble arg_x,
    gdouble arg_y,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_mutter_remote_desktop_session_call_notify_pointer_motion_absolute_finish (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_mutter_remote_desktop_session_call_notify_pointer_motion_absolute_sync (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    const gchar *arg_stream,
    gdouble arg_x,
    gdouble arg_y,
    GCancellable *cancellable,
    GError **error);

void org_gnome_mutter_remote_desktop_session_call_notify_touch_down (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    const gchar *arg_stream,
    guint arg_slot,
    gdouble arg_x,
    gdouble arg_y,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_mutter_remote_desktop_session_call_notify_touch_down_finish (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_mutter_remote_desktop_session_call_notify_touch_down_sync (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    const gchar *arg_stream,
    guint arg_slot,
    gdouble arg_x,
    gdouble arg_y,
    GCancellable *cancellable,
    GError **error);

void org_gnome_mutter_remote_desktop_session_call_notify_touch_motion (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    const gchar *arg_stream,
    guint arg_slot,
    gdouble arg_x,
    gdouble arg_y,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_mutter_remote_desktop_session_call_notify_touch_motion_finish (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_mutter_remote_desktop_session_call_notify_touch_motion_sync (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    const gchar *arg_stream,
    guint arg_slot,
    gdouble arg_x,
    gdouble arg_y,
    GCancellable *cancellable,
    GError **error);

void org_gnome_mutter_remote_desktop_session_call_notify_touch_up (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    guint arg_slot,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_mutter_remote_desktop_session_call_notify_touch_up_finish (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_mutter_remote_desktop_session_call_notify_touch_up_sync (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    guint arg_slot,
    GCancellable *cancellable,
    GError **error);

void org_gnome_mutter_remote_desktop_session_call_enable_clipboard (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    GVariant *arg_options,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_mutter_remote_desktop_session_call_enable_clipboard_finish (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_mutter_remote_desktop_session_call_enable_clipboard_sync (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    GVariant *arg_options,
    GCancellable *cancellable,
    GError **error);

void org_gnome_mutter_remote_desktop_session_call_disable_clipboard (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_mutter_remote_desktop_session_call_disable_clipboard_finish (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_mutter_remote_desktop_session_call_disable_clipboard_sync (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    GCancellable *cancellable,
    GError **error);

void org_gnome_mutter_remote_desktop_session_call_set_selection (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    GVariant *arg_options,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_mutter_remote_desktop_session_call_set_selection_finish (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_mutter_remote_desktop_session_call_set_selection_sync (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    GVariant *arg_options,
    GCancellable *cancellable,
    GError **error);

void org_gnome_mutter_remote_desktop_session_call_selection_write (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    guint arg_serial,
    GUnixFDList *fd_list,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_mutter_remote_desktop_session_call_selection_write_finish (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    GVariant ** out_fd,
    GUnixFDList **out_fd_list,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_mutter_remote_desktop_session_call_selection_write_sync (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    guint arg_serial,
    GUnixFDList  *fd_list,
    GVariant ** out_fd,
    GUnixFDList **out_fd_list,
    GCancellable *cancellable,
    GError **error);

void org_gnome_mutter_remote_desktop_session_call_selection_write_done (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    guint arg_serial,
    gboolean arg_success,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_mutter_remote_desktop_session_call_selection_write_done_finish (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_mutter_remote_desktop_session_call_selection_write_done_sync (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    guint arg_serial,
    gboolean arg_success,
    GCancellable *cancellable,
    GError **error);

void org_gnome_mutter_remote_desktop_session_call_selection_read (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    const gchar *arg_mime_type,
    GUnixFDList *fd_list,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_mutter_remote_desktop_session_call_selection_read_finish (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    GVariant ** out_fd,
    GUnixFDList **out_fd_list,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_mutter_remote_desktop_session_call_selection_read_sync (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    const gchar *arg_mime_type,
    GUnixFDList  *fd_list,
    GVariant ** out_fd,
    GUnixFDList **out_fd_list,
    GCancellable *cancellable,
    GError **error);

void org_gnome_mutter_remote_desktop_session_call_connect_to_eis (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    GVariant *arg_options,
    GUnixFDList *fd_list,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_mutter_remote_desktop_session_call_connect_to_eis_finish (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    GVariant ** out_fd,
    GUnixFDList **out_fd_list,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_mutter_remote_desktop_session_call_connect_to_eis_sync (
    OrgGnomeMutterRemoteDesktopSession *proxy,
    GVariant *arg_options,
    GUnixFDList  *fd_list,
    GVariant ** out_fd,
    GUnixFDList **out_fd_list,
    GCancellable *cancellable,
    GError **error);



/* D-Bus property accessors: */
const gchar *org_gnome_mutter_remote_desktop_session_get_session_id (OrgGnomeMutterRemoteDesktopSession *object);
gchar *org_gnome_mutter_remote_desktop_session_dup_session_id (OrgGnomeMutterRemoteDesktopSession *object);
void org_gnome_mutter_remote_desktop_session_set_session_id (OrgGnomeMutterRemoteDesktopSession *object, const gchar *value);

gboolean org_gnome_mutter_remote_desktop_session_get_caps_lock_state (OrgGnomeMutterRemoteDesktopSession *object);
void org_gnome_mutter_remote_desktop_session_set_caps_lock_state (OrgGnomeMutterRemoteDesktopSession *object, gboolean value);

gboolean org_gnome_mutter_remote_desktop_session_get_num_lock_state (OrgGnomeMutterRemoteDesktopSession *object);
void org_gnome_mutter_remote_desktop_session_set_num_lock_state (OrgGnomeMutterRemoteDesktopSession *object, gboolean value);


/* ---- */

#define TYPE_ORG_GNOME_MUTTER_REMOTE_DESKTOP_SESSION_PROXY (org_gnome_mutter_remote_desktop_session_proxy_get_type ())
#define ORG_GNOME_MUTTER_REMOTE_DESKTOP_SESSION_PROXY(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), TYPE_ORG_GNOME_MUTTER_REMOTE_DESKTOP_SESSION_PROXY, OrgGnomeMutterRemoteDesktopSessionProxy))
#define ORG_GNOME_MUTTER_REMOTE_DESKTOP_SESSION_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), TYPE_ORG_GNOME_MUTTER_REMOTE_DESKTOP_SESSION_PROXY, OrgGnomeMutterRemoteDesktopSessionProxyClass))
#define ORG_GNOME_MUTTER_REMOTE_DESKTOP_SESSION_PROXY_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), TYPE_ORG_GNOME_MUTTER_REMOTE_DESKTOP_SESSION_PROXY, OrgGnomeMutterRemoteDesktopSessionProxyClass))
#define IS_ORG_GNOME_MUTTER_REMOTE_DESKTOP_SESSION_PROXY(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), TYPE_ORG_GNOME_MUTTER_REMOTE_DESKTOP_SESSION_PROXY))
#define IS_ORG_GNOME_MUTTER_REMOTE_DESKTOP_SESSION_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), TYPE_ORG_GNOME_MUTTER_REMOTE_DESKTOP_SESSION_PROXY))

typedef struct _OrgGnomeMutterRemoteDesktopSessionProxy OrgGnomeMutterRemoteDesktopSessionProxy;
typedef struct _OrgGnomeMutterRemoteDesktopSessionProxyClass OrgGnomeMutterRemoteDesktopSessionProxyClass;
typedef struct _OrgGnomeMutterRemoteDesktopSessionProxyPrivate OrgGnomeMutterRemoteDesktopSessionProxyPrivate;

struct _OrgGnomeMutterRemoteDesktopSessionProxy
{
  /*< private >*/
  GDBusProxy parent_instance;
  OrgGnomeMutterRemoteDesktopSessionProxyPrivate *priv;
};

struct _OrgGnomeMutterRemoteDesktopSessionProxyClass
{
  GDBusProxyClass parent_class;
};

GType org_gnome_mutter_remote_desktop_session_proxy_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (OrgGnomeMutterRemoteDesktopSessionProxy, g_object_unref)
#endif

void org_gnome_mutter_remote_desktop_session_proxy_new (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
OrgGnomeMutterRemoteDesktopSession *org_gnome_mutter_remote_desktop_session_proxy_new_finish (
    GAsyncResult        *res,
    GError             **error);
OrgGnomeMutterRemoteDesktopSession *org_gnome_mutter_remote_desktop_session_proxy_new_sync (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);

void org_gnome_mutter_remote_desktop_session_proxy_new_for_bus (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
OrgGnomeMutterRemoteDesktopSession *org_gnome_mutter_remote_desktop_session_proxy_new_for_bus_finish (
    GAsyncResult        *res,
    GError             **error);
OrgGnomeMutterRemoteDesktopSession *org_gnome_mutter_remote_desktop_session_proxy_new_for_bus_sync (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);


/* ---- */

#define TYPE_ORG_GNOME_MUTTER_REMOTE_DESKTOP_SESSION_SKELETON (org_gnome_mutter_remote_desktop_session_skeleton_get_type ())
#define ORG_GNOME_MUTTER_REMOTE_DESKTOP_SESSION_SKELETON(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), TYPE_ORG_GNOME_MUTTER_REMOTE_DESKTOP_SESSION_SKELETON, OrgGnomeMutterRemoteDesktopSessionSkeleton))
#define ORG_GNOME_MUTTER_REMOTE_DESKTOP_SESSION_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), TYPE_ORG_GNOME_MUTTER_REMOTE_DESKTOP_SESSION_SKELETON, OrgGnomeMutterRemoteDesktopSessionSkeletonClass))
#define ORG_GNOME_MUTTER_REMOTE_DESKTOP_SESSION_SKELETON_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), TYPE_ORG_GNOME_MUTTER_REMOTE_DESKTOP_SESSION_SKELETON, OrgGnomeMutterRemoteDesktopSessionSkeletonClass))
#define IS_ORG_GNOME_MUTTER_REMOTE_DESKTOP_SESSION_SKELETON(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), TYPE_ORG_GNOME_MUTTER_REMOTE_DESKTOP_SESSION_SKELETON))
#define IS_ORG_GNOME_MUTTER_REMOTE_DESKTOP_SESSION_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), TYPE_ORG_GNOME_MUTTER_REMOTE_DESKTOP_SESSION_SKELETON))

typedef struct _OrgGnomeMutterRemoteDesktopSessionSkeleton OrgGnomeMutterRemoteDesktopSessionSkeleton;
typedef struct _OrgGnomeMutterRemoteDesktopSessionSkeletonClass OrgGnomeMutterRemoteDesktopSessionSkeletonClass;
typedef struct _OrgGnomeMutterRemoteDesktopSessionSkeletonPrivate OrgGnomeMutterRemoteDesktopSessionSkeletonPrivate;

struct _OrgGnomeMutterRemoteDesktopSessionSkeleton
{
  /*< private >*/
  GDBusInterfaceSkeleton parent_instance;
  OrgGnomeMutterRemoteDesktopSessionSkeletonPrivate *priv;
};

struct _OrgGnomeMutterRemoteDesktopSessionSkeletonClass
{
  GDBusInterfaceSkeletonClass parent_class;
};

GType org_gnome_mutter_remote_desktop_session_skeleton_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (OrgGnomeMutterRemoteDesktopSessionSkeleton, g_object_unref)
#endif

OrgGnomeMutterRemoteDesktopSession *org_gnome_mutter_remote_desktop_session_skeleton_new (void);


/* ------------------------------------------------------------------------ */
/* Declarations for org.gnome.Mutter.ScreenCast */

#define TYPE_ORG_GNOME_MUTTER_SCREEN_CAST (org_gnome_mutter_screen_cast_get_type ())
#define ORG_GNOME_MUTTER_SCREEN_CAST(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), TYPE_ORG_GNOME_MUTTER_SCREEN_CAST, OrgGnomeMutterScreenCast))
#define IS_ORG_GNOME_MUTTER_SCREEN_CAST(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), TYPE_ORG_GNOME_MUTTER_SCREEN_CAST))
#define ORG_GNOME_MUTTER_SCREEN_CAST_GET_IFACE(o) (G_TYPE_INSTANCE_GET_INTERFACE ((o), TYPE_ORG_GNOME_MUTTER_SCREEN_CAST, OrgGnomeMutterScreenCastIface))

struct _OrgGnomeMutterScreenCast;
typedef struct _OrgGnomeMutterScreenCast OrgGnomeMutterScreenCast;
typedef struct _OrgGnomeMutterScreenCastIface OrgGnomeMutterScreenCastIface;

struct _OrgGnomeMutterScreenCastIface
{
  GTypeInterface parent_iface;


  gboolean (*handle_create_session) (
    OrgGnomeMutterScreenCast *object,
    GDBusMethodInvocation *invocation,
    GVariant *arg_properties);

  gint  (*get_version) (OrgGnomeMutterScreenCast *object);

};

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (OrgGnomeMutterScreenCast, g_object_unref)
#endif

GType org_gnome_mutter_screen_cast_get_type (void) G_GNUC_CONST;

GDBusInterfaceInfo *org_gnome_mutter_screen_cast_interface_info (void);
guint org_gnome_mutter_screen_cast_override_properties (GObjectClass *klass, guint property_id_begin);


/* D-Bus method call completion functions: */
void org_gnome_mutter_screen_cast_complete_create_session (
    OrgGnomeMutterScreenCast *object,
    GDBusMethodInvocation *invocation,
    const gchar *session_path);



/* D-Bus method calls: */
void org_gnome_mutter_screen_cast_call_create_session (
    OrgGnomeMutterScreenCast *proxy,
    GVariant *arg_properties,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_mutter_screen_cast_call_create_session_finish (
    OrgGnomeMutterScreenCast *proxy,
    gchar ** out_session_path,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_mutter_screen_cast_call_create_session_sync (
    OrgGnomeMutterScreenCast *proxy,
    GVariant *arg_properties,
    gchar ** out_session_path,
    GCancellable *cancellable,
    GError **error);



/* D-Bus property accessors: */
gint org_gnome_mutter_screen_cast_get_version (OrgGnomeMutterScreenCast *object);
void org_gnome_mutter_screen_cast_set_version (OrgGnomeMutterScreenCast *object, gint value);


/* ---- */

#define TYPE_ORG_GNOME_MUTTER_SCREEN_CAST_PROXY (org_gnome_mutter_screen_cast_proxy_get_type ())
#define ORG_GNOME_MUTTER_SCREEN_CAST_PROXY(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), TYPE_ORG_GNOME_MUTTER_SCREEN_CAST_PROXY, OrgGnomeMutterScreenCastProxy))
#define ORG_GNOME_MUTTER_SCREEN_CAST_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), TYPE_ORG_GNOME_MUTTER_SCREEN_CAST_PROXY, OrgGnomeMutterScreenCastProxyClass))
#define ORG_GNOME_MUTTER_SCREEN_CAST_PROXY_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), TYPE_ORG_GNOME_MUTTER_SCREEN_CAST_PROXY, OrgGnomeMutterScreenCastProxyClass))
#define IS_ORG_GNOME_MUTTER_SCREEN_CAST_PROXY(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), TYPE_ORG_GNOME_MUTTER_SCREEN_CAST_PROXY))
#define IS_ORG_GNOME_MUTTER_SCREEN_CAST_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), TYPE_ORG_GNOME_MUTTER_SCREEN_CAST_PROXY))

typedef struct _OrgGnomeMutterScreenCastProxy OrgGnomeMutterScreenCastProxy;
typedef struct _OrgGnomeMutterScreenCastProxyClass OrgGnomeMutterScreenCastProxyClass;
typedef struct _OrgGnomeMutterScreenCastProxyPrivate OrgGnomeMutterScreenCastProxyPrivate;

struct _OrgGnomeMutterScreenCastProxy
{
  /*< private >*/
  GDBusProxy parent_instance;
  OrgGnomeMutterScreenCastProxyPrivate *priv;
};

struct _OrgGnomeMutterScreenCastProxyClass
{
  GDBusProxyClass parent_class;
};

GType org_gnome_mutter_screen_cast_proxy_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (OrgGnomeMutterScreenCastProxy, g_object_unref)
#endif

void org_gnome_mutter_screen_cast_proxy_new (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
OrgGnomeMutterScreenCast *org_gnome_mutter_screen_cast_proxy_new_finish (
    GAsyncResult        *res,
    GError             **error);
OrgGnomeMutterScreenCast *org_gnome_mutter_screen_cast_proxy_new_sync (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);

void org_gnome_mutter_screen_cast_proxy_new_for_bus (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
OrgGnomeMutterScreenCast *org_gnome_mutter_screen_cast_proxy_new_for_bus_finish (
    GAsyncResult        *res,
    GError             **error);
OrgGnomeMutterScreenCast *org_gnome_mutter_screen_cast_proxy_new_for_bus_sync (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);


/* ---- */

#define TYPE_ORG_GNOME_MUTTER_SCREEN_CAST_SKELETON (org_gnome_mutter_screen_cast_skeleton_get_type ())
#define ORG_GNOME_MUTTER_SCREEN_CAST_SKELETON(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), TYPE_ORG_GNOME_MUTTER_SCREEN_CAST_SKELETON, OrgGnomeMutterScreenCastSkeleton))
#define ORG_GNOME_MUTTER_SCREEN_CAST_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), TYPE_ORG_GNOME_MUTTER_SCREEN_CAST_SKELETON, OrgGnomeMutterScreenCastSkeletonClass))
#define ORG_GNOME_MUTTER_SCREEN_CAST_SKELETON_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), TYPE_ORG_GNOME_MUTTER_SCREEN_CAST_SKELETON, OrgGnomeMutterScreenCastSkeletonClass))
#define IS_ORG_GNOME_MUTTER_SCREEN_CAST_SKELETON(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), TYPE_ORG_GNOME_MUTTER_SCREEN_CAST_SKELETON))
#define IS_ORG_GNOME_MUTTER_SCREEN_CAST_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), TYPE_ORG_GNOME_MUTTER_SCREEN_CAST_SKELETON))

typedef struct _OrgGnomeMutterScreenCastSkeleton OrgGnomeMutterScreenCastSkeleton;
typedef struct _OrgGnomeMutterScreenCastSkeletonClass OrgGnomeMutterScreenCastSkeletonClass;
typedef struct _OrgGnomeMutterScreenCastSkeletonPrivate OrgGnomeMutterScreenCastSkeletonPrivate;

struct _OrgGnomeMutterScreenCastSkeleton
{
  /*< private >*/
  GDBusInterfaceSkeleton parent_instance;
  OrgGnomeMutterScreenCastSkeletonPrivate *priv;
};

struct _OrgGnomeMutterScreenCastSkeletonClass
{
  GDBusInterfaceSkeletonClass parent_class;
};

GType org_gnome_mutter_screen_cast_skeleton_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (OrgGnomeMutterScreenCastSkeleton, g_object_unref)
#endif

OrgGnomeMutterScreenCast *org_gnome_mutter_screen_cast_skeleton_new (void);


/* ------------------------------------------------------------------------ */
/* Declarations for org.gnome.Mutter.ScreenCast.Session */

#define TYPE_ORG_GNOME_MUTTER_SCREEN_CAST_SESSION (org_gnome_mutter_screen_cast_session_get_type ())
#define ORG_GNOME_MUTTER_SCREEN_CAST_SESSION(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), TYPE_ORG_GNOME_MUTTER_SCREEN_CAST_SESSION, OrgGnomeMutterScreenCastSession))
#define IS_ORG_GNOME_MUTTER_SCREEN_CAST_SESSION(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), TYPE_ORG_GNOME_MUTTER_SCREEN_CAST_SESSION))
#define ORG_GNOME_MUTTER_SCREEN_CAST_SESSION_GET_IFACE(o) (G_TYPE_INSTANCE_GET_INTERFACE ((o), TYPE_ORG_GNOME_MUTTER_SCREEN_CAST_SESSION, OrgGnomeMutterScreenCastSessionIface))

struct _OrgGnomeMutterScreenCastSession;
typedef struct _OrgGnomeMutterScreenCastSession OrgGnomeMutterScreenCastSession;
typedef struct _OrgGnomeMutterScreenCastSessionIface OrgGnomeMutterScreenCastSessionIface;

struct _OrgGnomeMutterScreenCastSessionIface
{
  GTypeInterface parent_iface;


  gboolean (*handle_record_area) (
    OrgGnomeMutterScreenCastSession *object,
    GDBusMethodInvocation *invocation,
    gint arg_x,
    gint arg_y,
    gint arg_width,
    gint arg_height,
    GVariant *arg_properties);

  gboolean (*handle_record_monitor) (
    OrgGnomeMutterScreenCastSession *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_connector,
    GVariant *arg_properties);

  gboolean (*handle_record_virtual) (
    OrgGnomeMutterScreenCastSession *object,
    GDBusMethodInvocation *invocation,
    GVariant *arg_properties);

  gboolean (*handle_record_window) (
    OrgGnomeMutterScreenCastSession *object,
    GDBusMethodInvocation *invocation,
    GVariant *arg_properties);

  gboolean (*handle_start) (
    OrgGnomeMutterScreenCastSession *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_stop) (
    OrgGnomeMutterScreenCastSession *object,
    GDBusMethodInvocation *invocation);

  void (*closed) (
    OrgGnomeMutterScreenCastSession *object);

};

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (OrgGnomeMutterScreenCastSession, g_object_unref)
#endif

GType org_gnome_mutter_screen_cast_session_get_type (void) G_GNUC_CONST;

GDBusInterfaceInfo *org_gnome_mutter_screen_cast_session_interface_info (void);
guint org_gnome_mutter_screen_cast_session_override_properties (GObjectClass *klass, guint property_id_begin);


/* D-Bus method call completion functions: */
void org_gnome_mutter_screen_cast_session_complete_start (
    OrgGnomeMutterScreenCastSession *object,
    GDBusMethodInvocation *invocation);

void org_gnome_mutter_screen_cast_session_complete_stop (
    OrgGnomeMutterScreenCastSession *object,
    GDBusMethodInvocation *invocation);

void org_gnome_mutter_screen_cast_session_complete_record_monitor (
    OrgGnomeMutterScreenCastSession *object,
    GDBusMethodInvocation *invocation,
    const gchar *stream_path);

void org_gnome_mutter_screen_cast_session_complete_record_window (
    OrgGnomeMutterScreenCastSession *object,
    GDBusMethodInvocation *invocation,
    const gchar *stream_path);

void org_gnome_mutter_screen_cast_session_complete_record_area (
    OrgGnomeMutterScreenCastSession *object,
    GDBusMethodInvocation *invocation,
    const gchar *stream_path);

void org_gnome_mutter_screen_cast_session_complete_record_virtual (
    OrgGnomeMutterScreenCastSession *object,
    GDBusMethodInvocation *invocation,
    const gchar *stream_path);



/* D-Bus signal emissions functions: */
void org_gnome_mutter_screen_cast_session_emit_closed (
    OrgGnomeMutterScreenCastSession *object);



/* D-Bus method calls: */
void org_gnome_mutter_screen_cast_session_call_start (
    OrgGnomeMutterScreenCastSession *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_mutter_screen_cast_session_call_start_finish (
    OrgGnomeMutterScreenCastSession *proxy,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_mutter_screen_cast_session_call_start_sync (
    OrgGnomeMutterScreenCastSession *proxy,
    GCancellable *cancellable,
    GError **error);

void org_gnome_mutter_screen_cast_session_call_stop (
    OrgGnomeMutterScreenCastSession *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_mutter_screen_cast_session_call_stop_finish (
    OrgGnomeMutterScreenCastSession *proxy,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_mutter_screen_cast_session_call_stop_sync (
    OrgGnomeMutterScreenCastSession *proxy,
    GCancellable *cancellable,
    GError **error);

void org_gnome_mutter_screen_cast_session_call_record_monitor (
    OrgGnomeMutterScreenCastSession *proxy,
    const gchar *arg_connector,
    GVariant *arg_properties,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_mutter_screen_cast_session_call_record_monitor_finish (
    OrgGnomeMutterScreenCastSession *proxy,
    gchar ** out_stream_path,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_mutter_screen_cast_session_call_record_monitor_sync (
    OrgGnomeMutterScreenCastSession *proxy,
    const gchar *arg_connector,
    GVariant *arg_properties,
    gchar ** out_stream_path,
    GCancellable *cancellable,
    GError **error);

void org_gnome_mutter_screen_cast_session_call_record_window (
    OrgGnomeMutterScreenCastSession *proxy,
    GVariant *arg_properties,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_mutter_screen_cast_session_call_record_window_finish (
    OrgGnomeMutterScreenCastSession *proxy,
    gchar ** out_stream_path,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_mutter_screen_cast_session_call_record_window_sync (
    OrgGnomeMutterScreenCastSession *proxy,
    GVariant *arg_properties,
    gchar ** out_stream_path,
    GCancellable *cancellable,
    GError **error);

void org_gnome_mutter_screen_cast_session_call_record_area (
    OrgGnomeMutterScreenCastSession *proxy,
    gint arg_x,
    gint arg_y,
    gint arg_width,
    gint arg_height,
    GVariant *arg_properties,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_mutter_screen_cast_session_call_record_area_finish (
    OrgGnomeMutterScreenCastSession *proxy,
    gchar ** out_stream_path,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_mutter_screen_cast_session_call_record_area_sync (
    OrgGnomeMutterScreenCastSession *proxy,
    gint arg_x,
    gint arg_y,
    gint arg_width,
    gint arg_height,
    GVariant *arg_properties,
    gchar ** out_stream_path,
    GCancellable *cancellable,
    GError **error);

void org_gnome_mutter_screen_cast_session_call_record_virtual (
    OrgGnomeMutterScreenCastSession *proxy,
    GVariant *arg_properties,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_mutter_screen_cast_session_call_record_virtual_finish (
    OrgGnomeMutterScreenCastSession *proxy,
    gchar ** out_stream_path,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_mutter_screen_cast_session_call_record_virtual_sync (
    OrgGnomeMutterScreenCastSession *proxy,
    GVariant *arg_properties,
    gchar ** out_stream_path,
    GCancellable *cancellable,
    GError **error);



/* ---- */

#define TYPE_ORG_GNOME_MUTTER_SCREEN_CAST_SESSION_PROXY (org_gnome_mutter_screen_cast_session_proxy_get_type ())
#define ORG_GNOME_MUTTER_SCREEN_CAST_SESSION_PROXY(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), TYPE_ORG_GNOME_MUTTER_SCREEN_CAST_SESSION_PROXY, OrgGnomeMutterScreenCastSessionProxy))
#define ORG_GNOME_MUTTER_SCREEN_CAST_SESSION_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), TYPE_ORG_GNOME_MUTTER_SCREEN_CAST_SESSION_PROXY, OrgGnomeMutterScreenCastSessionProxyClass))
#define ORG_GNOME_MUTTER_SCREEN_CAST_SESSION_PROXY_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), TYPE_ORG_GNOME_MUTTER_SCREEN_CAST_SESSION_PROXY, OrgGnomeMutterScreenCastSessionProxyClass))
#define IS_ORG_GNOME_MUTTER_SCREEN_CAST_SESSION_PROXY(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), TYPE_ORG_GNOME_MUTTER_SCREEN_CAST_SESSION_PROXY))
#define IS_ORG_GNOME_MUTTER_SCREEN_CAST_SESSION_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), TYPE_ORG_GNOME_MUTTER_SCREEN_CAST_SESSION_PROXY))

typedef struct _OrgGnomeMutterScreenCastSessionProxy OrgGnomeMutterScreenCastSessionProxy;
typedef struct _OrgGnomeMutterScreenCastSessionProxyClass OrgGnomeMutterScreenCastSessionProxyClass;
typedef struct _OrgGnomeMutterScreenCastSessionProxyPrivate OrgGnomeMutterScreenCastSessionProxyPrivate;

struct _OrgGnomeMutterScreenCastSessionProxy
{
  /*< private >*/
  GDBusProxy parent_instance;
  OrgGnomeMutterScreenCastSessionProxyPrivate *priv;
};

struct _OrgGnomeMutterScreenCastSessionProxyClass
{
  GDBusProxyClass parent_class;
};

GType org_gnome_mutter_screen_cast_session_proxy_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (OrgGnomeMutterScreenCastSessionProxy, g_object_unref)
#endif

void org_gnome_mutter_screen_cast_session_proxy_new (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
OrgGnomeMutterScreenCastSession *org_gnome_mutter_screen_cast_session_proxy_new_finish (
    GAsyncResult        *res,
    GError             **error);
OrgGnomeMutterScreenCastSession *org_gnome_mutter_screen_cast_session_proxy_new_sync (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);

void org_gnome_mutter_screen_cast_session_proxy_new_for_bus (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
OrgGnomeMutterScreenCastSession *org_gnome_mutter_screen_cast_session_proxy_new_for_bus_finish (
    GAsyncResult        *res,
    GError             **error);
OrgGnomeMutterScreenCastSession *org_gnome_mutter_screen_cast_session_proxy_new_for_bus_sync (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);


/* ---- */

#define TYPE_ORG_GNOME_MUTTER_SCREEN_CAST_SESSION_SKELETON (org_gnome_mutter_screen_cast_session_skeleton_get_type ())
#define ORG_GNOME_MUTTER_SCREEN_CAST_SESSION_SKELETON(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), TYPE_ORG_GNOME_MUTTER_SCREEN_CAST_SESSION_SKELETON, OrgGnomeMutterScreenCastSessionSkeleton))
#define ORG_GNOME_MUTTER_SCREEN_CAST_SESSION_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), TYPE_ORG_GNOME_MUTTER_SCREEN_CAST_SESSION_SKELETON, OrgGnomeMutterScreenCastSessionSkeletonClass))
#define ORG_GNOME_MUTTER_SCREEN_CAST_SESSION_SKELETON_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), TYPE_ORG_GNOME_MUTTER_SCREEN_CAST_SESSION_SKELETON, OrgGnomeMutterScreenCastSessionSkeletonClass))
#define IS_ORG_GNOME_MUTTER_SCREEN_CAST_SESSION_SKELETON(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), TYPE_ORG_GNOME_MUTTER_SCREEN_CAST_SESSION_SKELETON))
#define IS_ORG_GNOME_MUTTER_SCREEN_CAST_SESSION_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), TYPE_ORG_GNOME_MUTTER_SCREEN_CAST_SESSION_SKELETON))

typedef struct _OrgGnomeMutterScreenCastSessionSkeleton OrgGnomeMutterScreenCastSessionSkeleton;
typedef struct _OrgGnomeMutterScreenCastSessionSkeletonClass OrgGnomeMutterScreenCastSessionSkeletonClass;
typedef struct _OrgGnomeMutterScreenCastSessionSkeletonPrivate OrgGnomeMutterScreenCastSessionSkeletonPrivate;

struct _OrgGnomeMutterScreenCastSessionSkeleton
{
  /*< private >*/
  GDBusInterfaceSkeleton parent_instance;
  OrgGnomeMutterScreenCastSessionSkeletonPrivate *priv;
};

struct _OrgGnomeMutterScreenCastSessionSkeletonClass
{
  GDBusInterfaceSkeletonClass parent_class;
};

GType org_gnome_mutter_screen_cast_session_skeleton_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (OrgGnomeMutterScreenCastSessionSkeleton, g_object_unref)
#endif

OrgGnomeMutterScreenCastSession *org_gnome_mutter_screen_cast_session_skeleton_new (void);


/* ------------------------------------------------------------------------ */
/* Declarations for org.gnome.Mutter.ScreenCast.Stream */

#define TYPE_ORG_GNOME_MUTTER_SCREEN_CAST_STREAM (org_gnome_mutter_screen_cast_stream_get_type ())
#define ORG_GNOME_MUTTER_SCREEN_CAST_STREAM(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), TYPE_ORG_GNOME_MUTTER_SCREEN_CAST_STREAM, OrgGnomeMutterScreenCastStream))
#define IS_ORG_GNOME_MUTTER_SCREEN_CAST_STREAM(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), TYPE_ORG_GNOME_MUTTER_SCREEN_CAST_STREAM))
#define ORG_GNOME_MUTTER_SCREEN_CAST_STREAM_GET_IFACE(o) (G_TYPE_INSTANCE_GET_INTERFACE ((o), TYPE_ORG_GNOME_MUTTER_SCREEN_CAST_STREAM, OrgGnomeMutterScreenCastStreamIface))

struct _OrgGnomeMutterScreenCastStream;
typedef struct _OrgGnomeMutterScreenCastStream OrgGnomeMutterScreenCastStream;
typedef struct _OrgGnomeMutterScreenCastStreamIface OrgGnomeMutterScreenCastStreamIface;

struct _OrgGnomeMutterScreenCastStreamIface
{
  GTypeInterface parent_iface;


  GVariant * (*get_parameters) (OrgGnomeMutterScreenCastStream *object);

  void (*pipewire_stream_added) (
    OrgGnomeMutterScreenCastStream *object,
    guint arg_node_id);

};

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (OrgGnomeMutterScreenCastStream, g_object_unref)
#endif

GType org_gnome_mutter_screen_cast_stream_get_type (void) G_GNUC_CONST;

GDBusInterfaceInfo *org_gnome_mutter_screen_cast_stream_interface_info (void);
guint org_gnome_mutter_screen_cast_stream_override_properties (GObjectClass *klass, guint property_id_begin);


/* D-Bus signal emissions functions: */
void org_gnome_mutter_screen_cast_stream_emit_pipewire_stream_added (
    OrgGnomeMutterScreenCastStream *object,
    guint arg_node_id);



/* D-Bus property accessors: */
GVariant *org_gnome_mutter_screen_cast_stream_get_parameters (OrgGnomeMutterScreenCastStream *object);
GVariant *org_gnome_mutter_screen_cast_stream_dup_parameters (OrgGnomeMutterScreenCastStream *object);
void org_gnome_mutter_screen_cast_stream_set_parameters (OrgGnomeMutterScreenCastStream *object, GVariant *value);


/* ---- */

#define TYPE_ORG_GNOME_MUTTER_SCREEN_CAST_STREAM_PROXY (org_gnome_mutter_screen_cast_stream_proxy_get_type ())
#define ORG_GNOME_MUTTER_SCREEN_CAST_STREAM_PROXY(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), TYPE_ORG_GNOME_MUTTER_SCREEN_CAST_STREAM_PROXY, OrgGnomeMutterScreenCastStreamProxy))
#define ORG_GNOME_MUTTER_SCREEN_CAST_STREAM_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), TYPE_ORG_GNOME_MUTTER_SCREEN_CAST_STREAM_PROXY, OrgGnomeMutterScreenCastStreamProxyClass))
#define ORG_GNOME_MUTTER_SCREEN_CAST_STREAM_PROXY_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), TYPE_ORG_GNOME_MUTTER_SCREEN_CAST_STREAM_PROXY, OrgGnomeMutterScreenCastStreamProxyClass))
#define IS_ORG_GNOME_MUTTER_SCREEN_CAST_STREAM_PROXY(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), TYPE_ORG_GNOME_MUTTER_SCREEN_CAST_STREAM_PROXY))
#define IS_ORG_GNOME_MUTTER_SCREEN_CAST_STREAM_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), TYPE_ORG_GNOME_MUTTER_SCREEN_CAST_STREAM_PROXY))

typedef struct _OrgGnomeMutterScreenCastStreamProxy OrgGnomeMutterScreenCastStreamProxy;
typedef struct _OrgGnomeMutterScreenCastStreamProxyClass OrgGnomeMutterScreenCastStreamProxyClass;
typedef struct _OrgGnomeMutterScreenCastStreamProxyPrivate OrgGnomeMutterScreenCastStreamProxyPrivate;

struct _OrgGnomeMutterScreenCastStreamProxy
{
  /*< private >*/
  GDBusProxy parent_instance;
  OrgGnomeMutterScreenCastStreamProxyPrivate *priv;
};

struct _OrgGnomeMutterScreenCastStreamProxyClass
{
  GDBusProxyClass parent_class;
};

GType org_gnome_mutter_screen_cast_stream_proxy_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (OrgGnomeMutterScreenCastStreamProxy, g_object_unref)
#endif

void org_gnome_mutter_screen_cast_stream_proxy_new (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
OrgGnomeMutterScreenCastStream *org_gnome_mutter_screen_cast_stream_proxy_new_finish (
    GAsyncResult        *res,
    GError             **error);
OrgGnomeMutterScreenCastStream *org_gnome_mutter_screen_cast_stream_proxy_new_sync (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);

void org_gnome_mutter_screen_cast_stream_proxy_new_for_bus (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
OrgGnomeMutterScreenCastStream *org_gnome_mutter_screen_cast_stream_proxy_new_for_bus_finish (
    GAsyncResult        *res,
    GError             **error);
OrgGnomeMutterScreenCastStream *org_gnome_mutter_screen_cast_stream_proxy_new_for_bus_sync (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);


/* ---- */

#define TYPE_ORG_GNOME_MUTTER_SCREEN_CAST_STREAM_SKELETON (org_gnome_mutter_screen_cast_stream_skeleton_get_type ())
#define ORG_GNOME_MUTTER_SCREEN_CAST_STREAM_SKELETON(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), TYPE_ORG_GNOME_MUTTER_SCREEN_CAST_STREAM_SKELETON, OrgGnomeMutterScreenCastStreamSkeleton))
#define ORG_GNOME_MUTTER_SCREEN_CAST_STREAM_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), TYPE_ORG_GNOME_MUTTER_SCREEN_CAST_STREAM_SKELETON, OrgGnomeMutterScreenCastStreamSkeletonClass))
#define ORG_GNOME_MUTTER_SCREEN_CAST_STREAM_SKELETON_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), TYPE_ORG_GNOME_MUTTER_SCREEN_CAST_STREAM_SKELETON, OrgGnomeMutterScreenCastStreamSkeletonClass))
#define IS_ORG_GNOME_MUTTER_SCREEN_CAST_STREAM_SKELETON(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), TYPE_ORG_GNOME_MUTTER_SCREEN_CAST_STREAM_SKELETON))
#define IS_ORG_GNOME_MUTTER_SCREEN_CAST_STREAM_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), TYPE_ORG_GNOME_MUTTER_SCREEN_CAST_STREAM_SKELETON))

typedef struct _OrgGnomeMutterScreenCastStreamSkeleton OrgGnomeMutterScreenCastStreamSkeleton;
typedef struct _OrgGnomeMutterScreenCastStreamSkeletonClass OrgGnomeMutterScreenCastStreamSkeletonClass;
typedef struct _OrgGnomeMutterScreenCastStreamSkeletonPrivate OrgGnomeMutterScreenCastStreamSkeletonPrivate;

struct _OrgGnomeMutterScreenCastStreamSkeleton
{
  /*< private >*/
  GDBusInterfaceSkeleton parent_instance;
  OrgGnomeMutterScreenCastStreamSkeletonPrivate *priv;
};

struct _OrgGnomeMutterScreenCastStreamSkeletonClass
{
  GDBusInterfaceSkeletonClass parent_class;
};

GType org_gnome_mutter_screen_cast_stream_skeleton_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (OrgGnomeMutterScreenCastStreamSkeleton, g_object_unref)
#endif

OrgGnomeMutterScreenCastStream *org_gnome_mutter_screen_cast_stream_skeleton_new (void);


/* ------------------------------------------------------------------------ */
/* Declarations for org.gnome.Shell.Introspect */

#define TYPE_ORG_GNOME_SHELL_INTROSPECT (org_gnome_shell_introspect_get_type ())
#define ORG_GNOME_SHELL_INTROSPECT(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), TYPE_ORG_GNOME_SHELL_INTROSPECT, OrgGnomeShellIntrospect))
#define IS_ORG_GNOME_SHELL_INTROSPECT(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), TYPE_ORG_GNOME_SHELL_INTROSPECT))
#define ORG_GNOME_SHELL_INTROSPECT_GET_IFACE(o) (G_TYPE_INSTANCE_GET_INTERFACE ((o), TYPE_ORG_GNOME_SHELL_INTROSPECT, OrgGnomeShellIntrospectIface))

struct _OrgGnomeShellIntrospect;
typedef struct _OrgGnomeShellIntrospect OrgGnomeShellIntrospect;
typedef struct _OrgGnomeShellIntrospectIface OrgGnomeShellIntrospectIface;

struct _OrgGnomeShellIntrospectIface
{
  GTypeInterface parent_iface;



  gboolean (*handle_get_running_applications) (
    OrgGnomeShellIntrospect *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_get_windows) (
    OrgGnomeShellIntrospect *object,
    GDBusMethodInvocation *invocation);

  gboolean  (*get_animations_enabled) (OrgGnomeShellIntrospect *object);

  GVariant * (*get_screen_size) (OrgGnomeShellIntrospect *object);

  guint  (*get_version) (OrgGnomeShellIntrospect *object);

  void (*running_applications_changed) (
    OrgGnomeShellIntrospect *object);

  void (*windows_changed) (
    OrgGnomeShellIntrospect *object);

};

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (OrgGnomeShellIntrospect, g_object_unref)
#endif

GType org_gnome_shell_introspect_get_type (void) G_GNUC_CONST;

GDBusInterfaceInfo *org_gnome_shell_introspect_interface_info (void);
guint org_gnome_shell_introspect_override_properties (GObjectClass *klass, guint property_id_begin);


/* D-Bus method call completion functions: */
void org_gnome_shell_introspect_complete_get_running_applications (
    OrgGnomeShellIntrospect *object,
    GDBusMethodInvocation *invocation,
    GVariant *apps);

void org_gnome_shell_introspect_complete_get_windows (
    OrgGnomeShellIntrospect *object,
    GDBusMethodInvocation *invocation,
    GVariant *windows);



/* D-Bus signal emissions functions: */
void org_gnome_shell_introspect_emit_running_applications_changed (
    OrgGnomeShellIntrospect *object);

void org_gnome_shell_introspect_emit_windows_changed (
    OrgGnomeShellIntrospect *object);



/* D-Bus method calls: */
void org_gnome_shell_introspect_call_get_running_applications (
    OrgGnomeShellIntrospect *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_shell_introspect_call_get_running_applications_finish (
    OrgGnomeShellIntrospect *proxy,
    GVariant ** out_apps,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_shell_introspect_call_get_running_applications_sync (
    OrgGnomeShellIntrospect *proxy,
    GVariant ** out_apps,
    GCancellable *cancellable,
    GError **error);

void org_gnome_shell_introspect_call_get_windows (
    OrgGnomeShellIntrospect *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_shell_introspect_call_get_windows_finish (
    OrgGnomeShellIntrospect *proxy,
    GVariant ** out_windows,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_shell_introspect_call_get_windows_sync (
    OrgGnomeShellIntrospect *proxy,
    GVariant ** out_windows,
    GCancellable *cancellable,
    GError **error);



/* D-Bus property accessors: */
gboolean org_gnome_shell_introspect_get_animations_enabled (OrgGnomeShellIntrospect *object);
void org_gnome_shell_introspect_set_animations_enabled (OrgGnomeShellIntrospect *object, gboolean value);

GVariant *org_gnome_shell_introspect_get_screen_size (OrgGnomeShellIntrospect *object);
GVariant *org_gnome_shell_introspect_dup_screen_size (OrgGnomeShellIntrospect *object);
void org_gnome_shell_introspect_set_screen_size (OrgGnomeShellIntrospect *object, GVariant *value);

guint org_gnome_shell_introspect_get_version (OrgGnomeShellIntrospect *object);
void org_gnome_shell_introspect_set_version (OrgGnomeShellIntrospect *object, guint value);


/* ---- */

#define TYPE_ORG_GNOME_SHELL_INTROSPECT_PROXY (org_gnome_shell_introspect_proxy_get_type ())
#define ORG_GNOME_SHELL_INTROSPECT_PROXY(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), TYPE_ORG_GNOME_SHELL_INTROSPECT_PROXY, OrgGnomeShellIntrospectProxy))
#define ORG_GNOME_SHELL_INTROSPECT_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), TYPE_ORG_GNOME_SHELL_INTROSPECT_PROXY, OrgGnomeShellIntrospectProxyClass))
#define ORG_GNOME_SHELL_INTROSPECT_PROXY_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), TYPE_ORG_GNOME_SHELL_INTROSPECT_PROXY, OrgGnomeShellIntrospectProxyClass))
#define IS_ORG_GNOME_SHELL_INTROSPECT_PROXY(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), TYPE_ORG_GNOME_SHELL_INTROSPECT_PROXY))
#define IS_ORG_GNOME_SHELL_INTROSPECT_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), TYPE_ORG_GNOME_SHELL_INTROSPECT_PROXY))

typedef struct _OrgGnomeShellIntrospectProxy OrgGnomeShellIntrospectProxy;
typedef struct _OrgGnomeShellIntrospectProxyClass OrgGnomeShellIntrospectProxyClass;
typedef struct _OrgGnomeShellIntrospectProxyPrivate OrgGnomeShellIntrospectProxyPrivate;

struct _OrgGnomeShellIntrospectProxy
{
  /*< private >*/
  GDBusProxy parent_instance;
  OrgGnomeShellIntrospectProxyPrivate *priv;
};

struct _OrgGnomeShellIntrospectProxyClass
{
  GDBusProxyClass parent_class;
};

GType org_gnome_shell_introspect_proxy_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (OrgGnomeShellIntrospectProxy, g_object_unref)
#endif

void org_gnome_shell_introspect_proxy_new (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
OrgGnomeShellIntrospect *org_gnome_shell_introspect_proxy_new_finish (
    GAsyncResult        *res,
    GError             **error);
OrgGnomeShellIntrospect *org_gnome_shell_introspect_proxy_new_sync (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);

void org_gnome_shell_introspect_proxy_new_for_bus (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
OrgGnomeShellIntrospect *org_gnome_shell_introspect_proxy_new_for_bus_finish (
    GAsyncResult        *res,
    GError             **error);
OrgGnomeShellIntrospect *org_gnome_shell_introspect_proxy_new_for_bus_sync (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);


/* ---- */

#define TYPE_ORG_GNOME_SHELL_INTROSPECT_SKELETON (org_gnome_shell_introspect_skeleton_get_type ())
#define ORG_GNOME_SHELL_INTROSPECT_SKELETON(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), TYPE_ORG_GNOME_SHELL_INTROSPECT_SKELETON, OrgGnomeShellIntrospectSkeleton))
#define ORG_GNOME_SHELL_INTROSPECT_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), TYPE_ORG_GNOME_SHELL_INTROSPECT_SKELETON, OrgGnomeShellIntrospectSkeletonClass))
#define ORG_GNOME_SHELL_INTROSPECT_SKELETON_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), TYPE_ORG_GNOME_SHELL_INTROSPECT_SKELETON, OrgGnomeShellIntrospectSkeletonClass))
#define IS_ORG_GNOME_SHELL_INTROSPECT_SKELETON(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), TYPE_ORG_GNOME_SHELL_INTROSPECT_SKELETON))
#define IS_ORG_GNOME_SHELL_INTROSPECT_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), TYPE_ORG_GNOME_SHELL_INTROSPECT_SKELETON))

typedef struct _OrgGnomeShellIntrospectSkeleton OrgGnomeShellIntrospectSkeleton;
typedef struct _OrgGnomeShellIntrospectSkeletonClass OrgGnomeShellIntrospectSkeletonClass;
typedef struct _OrgGnomeShellIntrospectSkeletonPrivate OrgGnomeShellIntrospectSkeletonPrivate;

struct _OrgGnomeShellIntrospectSkeleton
{
  /*< private >*/
  GDBusInterfaceSkeleton parent_instance;
  OrgGnomeShellIntrospectSkeletonPrivate *priv;
};

struct _OrgGnomeShellIntrospectSkeletonClass
{
  GDBusInterfaceSkeletonClass parent_class;
};

GType org_gnome_shell_introspect_skeleton_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (OrgGnomeShellIntrospectSkeleton, g_object_unref)
#endif

OrgGnomeShellIntrospect *org_gnome_shell_introspect_skeleton_new (void);


/* ------------------------------------------------------------------------ */
/* Declarations for org.gnome.Shell.Screenshot */

#define TYPE_ORG_GNOME_SHELL_SCREENSHOT (org_gnome_shell_screenshot_get_type ())
#define ORG_GNOME_SHELL_SCREENSHOT(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), TYPE_ORG_GNOME_SHELL_SCREENSHOT, OrgGnomeShellScreenshot))
#define IS_ORG_GNOME_SHELL_SCREENSHOT(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), TYPE_ORG_GNOME_SHELL_SCREENSHOT))
#define ORG_GNOME_SHELL_SCREENSHOT_GET_IFACE(o) (G_TYPE_INSTANCE_GET_INTERFACE ((o), TYPE_ORG_GNOME_SHELL_SCREENSHOT, OrgGnomeShellScreenshotIface))

struct _OrgGnomeShellScreenshot;
typedef struct _OrgGnomeShellScreenshot OrgGnomeShellScreenshot;
typedef struct _OrgGnomeShellScreenshotIface OrgGnomeShellScreenshotIface;

struct _OrgGnomeShellScreenshotIface
{
  GTypeInterface parent_iface;

  gboolean (*handle_flash_area) (
    OrgGnomeShellScreenshot *object,
    GDBusMethodInvocation *invocation,
    gint arg_x,
    gint arg_y,
    gint arg_width,
    gint arg_height);

  gboolean (*handle_interactive_screenshot) (
    OrgGnomeShellScreenshot *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_pick_color) (
    OrgGnomeShellScreenshot *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_screenshot) (
    OrgGnomeShellScreenshot *object,
    GDBusMethodInvocation *invocation,
    gboolean arg_include_cursor,
    gboolean arg_flash,
    const gchar *arg_filename);

  gboolean (*handle_screenshot_area) (
    OrgGnomeShellScreenshot *object,
    GDBusMethodInvocation *invocation,
    gint arg_x,
    gint arg_y,
    gint arg_width,
    gint arg_height,
    gboolean arg_flash,
    const gchar *arg_filename);

  gboolean (*handle_screenshot_window) (
    OrgGnomeShellScreenshot *object,
    GDBusMethodInvocation *invocation,
    gboolean arg_include_frame,
    gboolean arg_include_cursor,
    gboolean arg_flash,
    const gchar *arg_filename);

  gboolean (*handle_select_area) (
    OrgGnomeShellScreenshot *object,
    GDBusMethodInvocation *invocation);

};

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (OrgGnomeShellScreenshot, g_object_unref)
#endif

GType org_gnome_shell_screenshot_get_type (void) G_GNUC_CONST;

GDBusInterfaceInfo *org_gnome_shell_screenshot_interface_info (void);
guint org_gnome_shell_screenshot_override_properties (GObjectClass *klass, guint property_id_begin);


/* D-Bus method call completion functions: */
void org_gnome_shell_screenshot_complete_interactive_screenshot (
    OrgGnomeShellScreenshot *object,
    GDBusMethodInvocation *invocation,
    gboolean success,
    const gchar *uri);

void org_gnome_shell_screenshot_complete_screenshot (
    OrgGnomeShellScreenshot *object,
    GDBusMethodInvocation *invocation,
    gboolean success,
    const gchar *filename_used);

void org_gnome_shell_screenshot_complete_screenshot_window (
    OrgGnomeShellScreenshot *object,
    GDBusMethodInvocation *invocation,
    gboolean success,
    const gchar *filename_used);

void org_gnome_shell_screenshot_complete_screenshot_area (
    OrgGnomeShellScreenshot *object,
    GDBusMethodInvocation *invocation,
    gboolean success,
    const gchar *filename_used);

void org_gnome_shell_screenshot_complete_flash_area (
    OrgGnomeShellScreenshot *object,
    GDBusMethodInvocation *invocation);

void org_gnome_shell_screenshot_complete_select_area (
    OrgGnomeShellScreenshot *object,
    GDBusMethodInvocation *invocation,
    gint x,
    gint y,
    gint width,
    gint height);

void org_gnome_shell_screenshot_complete_pick_color (
    OrgGnomeShellScreenshot *object,
    GDBusMethodInvocation *invocation,
    GVariant *result);



/* D-Bus method calls: */
void org_gnome_shell_screenshot_call_interactive_screenshot (
    OrgGnomeShellScreenshot *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_shell_screenshot_call_interactive_screenshot_finish (
    OrgGnomeShellScreenshot *proxy,
    gboolean* out_success,
    gchar ** out_uri,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_shell_screenshot_call_interactive_screenshot_sync (
    OrgGnomeShellScreenshot *proxy,
    gboolean* out_success,
    gchar ** out_uri,
    GCancellable *cancellable,
    GError **error);

void org_gnome_shell_screenshot_call_screenshot (
    OrgGnomeShellScreenshot *proxy,
    gboolean arg_include_cursor,
    gboolean arg_flash,
    const gchar *arg_filename,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_shell_screenshot_call_screenshot_finish (
    OrgGnomeShellScreenshot *proxy,
    gboolean* out_success,
    gchar ** out_filename_used,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_shell_screenshot_call_screenshot_sync (
    OrgGnomeShellScreenshot *proxy,
    gboolean arg_include_cursor,
    gboolean arg_flash,
    const gchar *arg_filename,
    gboolean* out_success,
    gchar ** out_filename_used,
    GCancellable *cancellable,
    GError **error);

void org_gnome_shell_screenshot_call_screenshot_window (
    OrgGnomeShellScreenshot *proxy,
    gboolean arg_include_frame,
    gboolean arg_include_cursor,
    gboolean arg_flash,
    const gchar *arg_filename,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_shell_screenshot_call_screenshot_window_finish (
    OrgGnomeShellScreenshot *proxy,
    gboolean* out_success,
    gchar ** out_filename_used,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_shell_screenshot_call_screenshot_window_sync (
    OrgGnomeShellScreenshot *proxy,
    gboolean arg_include_frame,
    gboolean arg_include_cursor,
    gboolean arg_flash,
    const gchar *arg_filename,
    gboolean* out_success,
    gchar ** out_filename_used,
    GCancellable *cancellable,
    GError **error);

void org_gnome_shell_screenshot_call_screenshot_area (
    OrgGnomeShellScreenshot *proxy,
    gint arg_x,
    gint arg_y,
    gint arg_width,
    gint arg_height,
    gboolean arg_flash,
    const gchar *arg_filename,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_shell_screenshot_call_screenshot_area_finish (
    OrgGnomeShellScreenshot *proxy,
    gboolean* out_success,
    gchar ** out_filename_used,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_shell_screenshot_call_screenshot_area_sync (
    OrgGnomeShellScreenshot *proxy,
    gint arg_x,
    gint arg_y,
    gint arg_width,
    gint arg_height,
    gboolean arg_flash,
    const gchar *arg_filename,
    gboolean* out_success,
    gchar ** out_filename_used,
    GCancellable *cancellable,
    GError **error);

void org_gnome_shell_screenshot_call_flash_area (
    OrgGnomeShellScreenshot *proxy,
    gint arg_x,
    gint arg_y,
    gint arg_width,
    gint arg_height,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_shell_screenshot_call_flash_area_finish (
    OrgGnomeShellScreenshot *proxy,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_shell_screenshot_call_flash_area_sync (
    OrgGnomeShellScreenshot *proxy,
    gint arg_x,
    gint arg_y,
    gint arg_width,
    gint arg_height,
    GCancellable *cancellable,
    GError **error);

void org_gnome_shell_screenshot_call_select_area (
    OrgGnomeShellScreenshot *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_shell_screenshot_call_select_area_finish (
    OrgGnomeShellScreenshot *proxy,
    gint* out_x,
    gint* out_y,
    gint* out_width,
    gint* out_height,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_shell_screenshot_call_select_area_sync (
    OrgGnomeShellScreenshot *proxy,
    gint* out_x,
    gint* out_y,
    gint* out_width,
    gint* out_height,
    GCancellable *cancellable,
    GError **error);

void org_gnome_shell_screenshot_call_pick_color (
    OrgGnomeShellScreenshot *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_shell_screenshot_call_pick_color_finish (
    OrgGnomeShellScreenshot *proxy,
    GVariant ** out_result,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_shell_screenshot_call_pick_color_sync (
    OrgGnomeShellScreenshot *proxy,
    GVariant ** out_result,
    GCancellable *cancellable,
    GError **error);



/* ---- */

#define TYPE_ORG_GNOME_SHELL_SCREENSHOT_PROXY (org_gnome_shell_screenshot_proxy_get_type ())
#define ORG_GNOME_SHELL_SCREENSHOT_PROXY(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), TYPE_ORG_GNOME_SHELL_SCREENSHOT_PROXY, OrgGnomeShellScreenshotProxy))
#define ORG_GNOME_SHELL_SCREENSHOT_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), TYPE_ORG_GNOME_SHELL_SCREENSHOT_PROXY, OrgGnomeShellScreenshotProxyClass))
#define ORG_GNOME_SHELL_SCREENSHOT_PROXY_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), TYPE_ORG_GNOME_SHELL_SCREENSHOT_PROXY, OrgGnomeShellScreenshotProxyClass))
#define IS_ORG_GNOME_SHELL_SCREENSHOT_PROXY(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), TYPE_ORG_GNOME_SHELL_SCREENSHOT_PROXY))
#define IS_ORG_GNOME_SHELL_SCREENSHOT_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), TYPE_ORG_GNOME_SHELL_SCREENSHOT_PROXY))

typedef struct _OrgGnomeShellScreenshotProxy OrgGnomeShellScreenshotProxy;
typedef struct _OrgGnomeShellScreenshotProxyClass OrgGnomeShellScreenshotProxyClass;
typedef struct _OrgGnomeShellScreenshotProxyPrivate OrgGnomeShellScreenshotProxyPrivate;

struct _OrgGnomeShellScreenshotProxy
{
  /*< private >*/
  GDBusProxy parent_instance;
  OrgGnomeShellScreenshotProxyPrivate *priv;
};

struct _OrgGnomeShellScreenshotProxyClass
{
  GDBusProxyClass parent_class;
};

GType org_gnome_shell_screenshot_proxy_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (OrgGnomeShellScreenshotProxy, g_object_unref)
#endif

void org_gnome_shell_screenshot_proxy_new (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
OrgGnomeShellScreenshot *org_gnome_shell_screenshot_proxy_new_finish (
    GAsyncResult        *res,
    GError             **error);
OrgGnomeShellScreenshot *org_gnome_shell_screenshot_proxy_new_sync (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);

void org_gnome_shell_screenshot_proxy_new_for_bus (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
OrgGnomeShellScreenshot *org_gnome_shell_screenshot_proxy_new_for_bus_finish (
    GAsyncResult        *res,
    GError             **error);
OrgGnomeShellScreenshot *org_gnome_shell_screenshot_proxy_new_for_bus_sync (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);


/* ---- */

#define TYPE_ORG_GNOME_SHELL_SCREENSHOT_SKELETON (org_gnome_shell_screenshot_skeleton_get_type ())
#define ORG_GNOME_SHELL_SCREENSHOT_SKELETON(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), TYPE_ORG_GNOME_SHELL_SCREENSHOT_SKELETON, OrgGnomeShellScreenshotSkeleton))
#define ORG_GNOME_SHELL_SCREENSHOT_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), TYPE_ORG_GNOME_SHELL_SCREENSHOT_SKELETON, OrgGnomeShellScreenshotSkeletonClass))
#define ORG_GNOME_SHELL_SCREENSHOT_SKELETON_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), TYPE_ORG_GNOME_SHELL_SCREENSHOT_SKELETON, OrgGnomeShellScreenshotSkeletonClass))
#define IS_ORG_GNOME_SHELL_SCREENSHOT_SKELETON(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), TYPE_ORG_GNOME_SHELL_SCREENSHOT_SKELETON))
#define IS_ORG_GNOME_SHELL_SCREENSHOT_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), TYPE_ORG_GNOME_SHELL_SCREENSHOT_SKELETON))

typedef struct _OrgGnomeShellScreenshotSkeleton OrgGnomeShellScreenshotSkeleton;
typedef struct _OrgGnomeShellScreenshotSkeletonClass OrgGnomeShellScreenshotSkeletonClass;
typedef struct _OrgGnomeShellScreenshotSkeletonPrivate OrgGnomeShellScreenshotSkeletonPrivate;

struct _OrgGnomeShellScreenshotSkeleton
{
  /*< private >*/
  GDBusInterfaceSkeleton parent_instance;
  OrgGnomeShellScreenshotSkeletonPrivate *priv;
};

struct _OrgGnomeShellScreenshotSkeletonClass
{
  GDBusInterfaceSkeletonClass parent_class;
};

GType org_gnome_shell_screenshot_skeleton_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (OrgGnomeShellScreenshotSkeleton, g_object_unref)
#endif

OrgGnomeShellScreenshot *org_gnome_shell_screenshot_skeleton_new (void);


/* ------------------------------------------------------------------------ */
/* Declarations for org.gnome.Shell */

#define TYPE_ORG_GNOME_SHELL (org_gnome_shell_get_type ())
#define ORG_GNOME_SHELL(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), TYPE_ORG_GNOME_SHELL, OrgGnomeShell))
#define IS_ORG_GNOME_SHELL(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), TYPE_ORG_GNOME_SHELL))
#define ORG_GNOME_SHELL_GET_IFACE(o) (G_TYPE_INSTANCE_GET_INTERFACE ((o), TYPE_ORG_GNOME_SHELL, OrgGnomeShellIface))

struct _OrgGnomeShell;
typedef struct _OrgGnomeShell OrgGnomeShell;
typedef struct _OrgGnomeShellIface OrgGnomeShellIface;

struct _OrgGnomeShellIface
{
  GTypeInterface parent_iface;



  gboolean (*handle_eval) (
    OrgGnomeShell *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_script);

  gboolean (*handle_focus_app) (
    OrgGnomeShell *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_id);

  gboolean (*handle_focus_search) (
    OrgGnomeShell *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_grab_accelerator) (
    OrgGnomeShell *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_accelerator,
    guint arg_modeFlags,
    guint arg_grabFlags);

  gboolean (*handle_grab_accelerators) (
    OrgGnomeShell *object,
    GDBusMethodInvocation *invocation,
    GVariant *arg_accelerators);

  gboolean (*handle_hide_monitor_labels) (
    OrgGnomeShell *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_screen_transition) (
    OrgGnomeShell *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_show_applications) (
    OrgGnomeShell *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_show_monitor_labels) (
    OrgGnomeShell *object,
    GDBusMethodInvocation *invocation,
    GVariant *arg_params);

  gboolean (*handle_show_osd) (
    OrgGnomeShell *object,
    GDBusMethodInvocation *invocation,
    GVariant *arg_params);

  gboolean (*handle_ungrab_accelerator) (
    OrgGnomeShell *object,
    GDBusMethodInvocation *invocation,
    guint arg_action);

  gboolean (*handle_ungrab_accelerators) (
    OrgGnomeShell *object,
    GDBusMethodInvocation *invocation,
    GVariant *arg_action);

  const gchar * (*get_mode) (OrgGnomeShell *object);

  gboolean  (*get_overview_active) (OrgGnomeShell *object);

  const gchar * (*get_shell_version) (OrgGnomeShell *object);

  void (*accelerator_activated) (
    OrgGnomeShell *object,
    guint arg_action,
    GVariant *arg_parameters);

  void (*accelerator_deactivated) (
    OrgGnomeShell *object,
    guint arg_action,
    GVariant *arg_parameters);

};

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (OrgGnomeShell, g_object_unref)
#endif

GType org_gnome_shell_get_type (void) G_GNUC_CONST;

GDBusInterfaceInfo *org_gnome_shell_interface_info (void);
guint org_gnome_shell_override_properties (GObjectClass *klass, guint property_id_begin);


/* D-Bus method call completion functions: */
void org_gnome_shell_complete_eval (
    OrgGnomeShell *object,
    GDBusMethodInvocation *invocation,
    gboolean success,
    const gchar *result);

void org_gnome_shell_complete_focus_search (
    OrgGnomeShell *object,
    GDBusMethodInvocation *invocation);

void org_gnome_shell_complete_show_osd (
    OrgGnomeShell *object,
    GDBusMethodInvocation *invocation);

void org_gnome_shell_complete_show_monitor_labels (
    OrgGnomeShell *object,
    GDBusMethodInvocation *invocation);

void org_gnome_shell_complete_hide_monitor_labels (
    OrgGnomeShell *object,
    GDBusMethodInvocation *invocation);

void org_gnome_shell_complete_focus_app (
    OrgGnomeShell *object,
    GDBusMethodInvocation *invocation);

void org_gnome_shell_complete_show_applications (
    OrgGnomeShell *object,
    GDBusMethodInvocation *invocation);

void org_gnome_shell_complete_grab_accelerator (
    OrgGnomeShell *object,
    GDBusMethodInvocation *invocation,
    guint action);

void org_gnome_shell_complete_grab_accelerators (
    OrgGnomeShell *object,
    GDBusMethodInvocation *invocation,
    GVariant *actions);

void org_gnome_shell_complete_ungrab_accelerator (
    OrgGnomeShell *object,
    GDBusMethodInvocation *invocation,
    gboolean success);

void org_gnome_shell_complete_ungrab_accelerators (
    OrgGnomeShell *object,
    GDBusMethodInvocation *invocation,
    gboolean success);

void org_gnome_shell_complete_screen_transition (
    OrgGnomeShell *object,
    GDBusMethodInvocation *invocation);



/* D-Bus signal emissions functions: */
void org_gnome_shell_emit_accelerator_activated (
    OrgGnomeShell *object,
    guint arg_action,
    GVariant *arg_parameters);

void org_gnome_shell_emit_accelerator_deactivated (
    OrgGnomeShell *object,
    guint arg_action,
    GVariant *arg_parameters);



/* D-Bus method calls: */
void org_gnome_shell_call_eval (
    OrgGnomeShell *proxy,
    const gchar *arg_script,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_shell_call_eval_finish (
    OrgGnomeShell *proxy,
    gboolean* out_success,
    gchar ** out_result,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_shell_call_eval_sync (
    OrgGnomeShell *proxy,
    const gchar *arg_script,
    gboolean* out_success,
    gchar ** out_result,
    GCancellable *cancellable,
    GError **error);

void org_gnome_shell_call_focus_search (
    OrgGnomeShell *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_shell_call_focus_search_finish (
    OrgGnomeShell *proxy,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_shell_call_focus_search_sync (
    OrgGnomeShell *proxy,
    GCancellable *cancellable,
    GError **error);

void org_gnome_shell_call_show_osd (
    OrgGnomeShell *proxy,
    GVariant *arg_params,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_shell_call_show_osd_finish (
    OrgGnomeShell *proxy,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_shell_call_show_osd_sync (
    OrgGnomeShell *proxy,
    GVariant *arg_params,
    GCancellable *cancellable,
    GError **error);

void org_gnome_shell_call_show_monitor_labels (
    OrgGnomeShell *proxy,
    GVariant *arg_params,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_shell_call_show_monitor_labels_finish (
    OrgGnomeShell *proxy,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_shell_call_show_monitor_labels_sync (
    OrgGnomeShell *proxy,
    GVariant *arg_params,
    GCancellable *cancellable,
    GError **error);

void org_gnome_shell_call_hide_monitor_labels (
    OrgGnomeShell *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_shell_call_hide_monitor_labels_finish (
    OrgGnomeShell *proxy,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_shell_call_hide_monitor_labels_sync (
    OrgGnomeShell *proxy,
    GCancellable *cancellable,
    GError **error);

void org_gnome_shell_call_focus_app (
    OrgGnomeShell *proxy,
    const gchar *arg_id,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_shell_call_focus_app_finish (
    OrgGnomeShell *proxy,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_shell_call_focus_app_sync (
    OrgGnomeShell *proxy,
    const gchar *arg_id,
    GCancellable *cancellable,
    GError **error);

void org_gnome_shell_call_show_applications (
    OrgGnomeShell *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_shell_call_show_applications_finish (
    OrgGnomeShell *proxy,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_shell_call_show_applications_sync (
    OrgGnomeShell *proxy,
    GCancellable *cancellable,
    GError **error);

void org_gnome_shell_call_grab_accelerator (
    OrgGnomeShell *proxy,
    const gchar *arg_accelerator,
    guint arg_modeFlags,
    guint arg_grabFlags,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_shell_call_grab_accelerator_finish (
    OrgGnomeShell *proxy,
    guint* out_action,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_shell_call_grab_accelerator_sync (
    OrgGnomeShell *proxy,
    const gchar *arg_accelerator,
    guint arg_modeFlags,
    guint arg_grabFlags,
    guint* out_action,
    GCancellable *cancellable,
    GError **error);

void org_gnome_shell_call_grab_accelerators (
    OrgGnomeShell *proxy,
    GVariant *arg_accelerators,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_shell_call_grab_accelerators_finish (
    OrgGnomeShell *proxy,
    GVariant ** out_actions,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_shell_call_grab_accelerators_sync (
    OrgGnomeShell *proxy,
    GVariant *arg_accelerators,
    GVariant ** out_actions,
    GCancellable *cancellable,
    GError **error);

void org_gnome_shell_call_ungrab_accelerator (
    OrgGnomeShell *proxy,
    guint arg_action,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_shell_call_ungrab_accelerator_finish (
    OrgGnomeShell *proxy,
    gboolean* out_success,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_shell_call_ungrab_accelerator_sync (
    OrgGnomeShell *proxy,
    guint arg_action,
    gboolean* out_success,
    GCancellable *cancellable,
    GError **error);

void org_gnome_shell_call_ungrab_accelerators (
    OrgGnomeShell *proxy,
    GVariant *arg_action,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_shell_call_ungrab_accelerators_finish (
    OrgGnomeShell *proxy,
    gboolean* out_success,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_shell_call_ungrab_accelerators_sync (
    OrgGnomeShell *proxy,
    GVariant *arg_action,
    gboolean* out_success,
    GCancellable *cancellable,
    GError **error);

void org_gnome_shell_call_screen_transition (
    OrgGnomeShell *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gnome_shell_call_screen_transition_finish (
    OrgGnomeShell *proxy,
    GAsyncResult *res,
    GError **error);

gboolean org_gnome_shell_call_screen_transition_sync (
    OrgGnomeShell *proxy,
    GCancellable *cancellable,
    GError **error);



/* D-Bus property accessors: */
const gchar *org_gnome_shell_get_mode (OrgGnomeShell *object);
gchar *org_gnome_shell_dup_mode (OrgGnomeShell *object);
void org_gnome_shell_set_mode (OrgGnomeShell *object, const gchar *value);

gboolean org_gnome_shell_get_overview_active (OrgGnomeShell *object);
void org_gnome_shell_set_overview_active (OrgGnomeShell *object, gboolean value);

const gchar *org_gnome_shell_get_shell_version (OrgGnomeShell *object);
gchar *org_gnome_shell_dup_shell_version (OrgGnomeShell *object);
void org_gnome_shell_set_shell_version (OrgGnomeShell *object, const gchar *value);


/* ---- */

#define TYPE_ORG_GNOME_SHELL_PROXY (org_gnome_shell_proxy_get_type ())
#define ORG_GNOME_SHELL_PROXY(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), TYPE_ORG_GNOME_SHELL_PROXY, OrgGnomeShellProxy))
#define ORG_GNOME_SHELL_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), TYPE_ORG_GNOME_SHELL_PROXY, OrgGnomeShellProxyClass))
#define ORG_GNOME_SHELL_PROXY_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), TYPE_ORG_GNOME_SHELL_PROXY, OrgGnomeShellProxyClass))
#define IS_ORG_GNOME_SHELL_PROXY(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), TYPE_ORG_GNOME_SHELL_PROXY))
#define IS_ORG_GNOME_SHELL_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), TYPE_ORG_GNOME_SHELL_PROXY))

typedef struct _OrgGnomeShellProxy OrgGnomeShellProxy;
typedef struct _OrgGnomeShellProxyClass OrgGnomeShellProxyClass;
typedef struct _OrgGnomeShellProxyPrivate OrgGnomeShellProxyPrivate;

struct _OrgGnomeShellProxy
{
  /*< private >*/
  GDBusProxy parent_instance;
  OrgGnomeShellProxyPrivate *priv;
};

struct _OrgGnomeShellProxyClass
{
  GDBusProxyClass parent_class;
};

GType org_gnome_shell_proxy_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (OrgGnomeShellProxy, g_object_unref)
#endif

void org_gnome_shell_proxy_new (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
OrgGnomeShell *org_gnome_shell_proxy_new_finish (
    GAsyncResult        *res,
    GError             **error);
OrgGnomeShell *org_gnome_shell_proxy_new_sync (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);

void org_gnome_shell_proxy_new_for_bus (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
OrgGnomeShell *org_gnome_shell_proxy_new_for_bus_finish (
    GAsyncResult        *res,
    GError             **error);
OrgGnomeShell *org_gnome_shell_proxy_new_for_bus_sync (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);


/* ---- */

#define TYPE_ORG_GNOME_SHELL_SKELETON (org_gnome_shell_skeleton_get_type ())
#define ORG_GNOME_SHELL_SKELETON(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), TYPE_ORG_GNOME_SHELL_SKELETON, OrgGnomeShellSkeleton))
#define ORG_GNOME_SHELL_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), TYPE_ORG_GNOME_SHELL_SKELETON, OrgGnomeShellSkeletonClass))
#define ORG_GNOME_SHELL_SKELETON_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), TYPE_ORG_GNOME_SHELL_SKELETON, OrgGnomeShellSkeletonClass))
#define IS_ORG_GNOME_SHELL_SKELETON(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), TYPE_ORG_GNOME_SHELL_SKELETON))
#define IS_ORG_GNOME_SHELL_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), TYPE_ORG_GNOME_SHELL_SKELETON))

typedef struct _OrgGnomeShellSkeleton OrgGnomeShellSkeleton;
typedef struct _OrgGnomeShellSkeletonClass OrgGnomeShellSkeletonClass;
typedef struct _OrgGnomeShellSkeletonPrivate OrgGnomeShellSkeletonPrivate;

struct _OrgGnomeShellSkeleton
{
  /*< private >*/
  GDBusInterfaceSkeleton parent_instance;
  OrgGnomeShellSkeletonPrivate *priv;
};

struct _OrgGnomeShellSkeletonClass
{
  GDBusInterfaceSkeletonClass parent_class;
};

GType org_gnome_shell_skeleton_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (OrgGnomeShellSkeleton, g_object_unref)
#endif

OrgGnomeShell *org_gnome_shell_skeleton_new (void);


/* ------------------------------------------------------------------------ */
/* Declarations for org.gtk.Notifications */

#define TYPE_ORG_GTK_NOTIFICATIONS (org_gtk_notifications_get_type ())
#define ORG_GTK_NOTIFICATIONS(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), TYPE_ORG_GTK_NOTIFICATIONS, OrgGtkNotifications))
#define IS_ORG_GTK_NOTIFICATIONS(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), TYPE_ORG_GTK_NOTIFICATIONS))
#define ORG_GTK_NOTIFICATIONS_GET_IFACE(o) (G_TYPE_INSTANCE_GET_INTERFACE ((o), TYPE_ORG_GTK_NOTIFICATIONS, OrgGtkNotificationsIface))

struct _OrgGtkNotifications;
typedef struct _OrgGtkNotifications OrgGtkNotifications;
typedef struct _OrgGtkNotificationsIface OrgGtkNotificationsIface;

struct _OrgGtkNotificationsIface
{
  GTypeInterface parent_iface;


  gboolean (*handle_add_notification) (
    OrgGtkNotifications *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_app_id,
    const gchar *arg_id,
    GVariant *arg_notification);

  gboolean (*handle_remove_notification) (
    OrgGtkNotifications *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_app_id,
    const gchar *arg_id);

  void (*action_invoked) (
    OrgGtkNotifications *object,
    const gchar *arg_app_id,
    const gchar *arg_id,
    const gchar *arg_action,
    GVariant *arg_parameter,
    GVariant *arg_platform_data);

};

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (OrgGtkNotifications, g_object_unref)
#endif

GType org_gtk_notifications_get_type (void) G_GNUC_CONST;

GDBusInterfaceInfo *org_gtk_notifications_interface_info (void);
guint org_gtk_notifications_override_properties (GObjectClass *klass, guint property_id_begin);


/* D-Bus method call completion functions: */
void org_gtk_notifications_complete_add_notification (
    OrgGtkNotifications *object,
    GDBusMethodInvocation *invocation);

void org_gtk_notifications_complete_remove_notification (
    OrgGtkNotifications *object,
    GDBusMethodInvocation *invocation);



/* D-Bus signal emissions functions: */
void org_gtk_notifications_emit_action_invoked (
    OrgGtkNotifications *object,
    const gchar *arg_app_id,
    const gchar *arg_id,
    const gchar *arg_action,
    GVariant *arg_parameter,
    GVariant *arg_platform_data);



/* D-Bus method calls: */
void org_gtk_notifications_call_add_notification (
    OrgGtkNotifications *proxy,
    const gchar *arg_app_id,
    const gchar *arg_id,
    GVariant *arg_notification,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gtk_notifications_call_add_notification_finish (
    OrgGtkNotifications *proxy,
    GAsyncResult *res,
    GError **error);

gboolean org_gtk_notifications_call_add_notification_sync (
    OrgGtkNotifications *proxy,
    const gchar *arg_app_id,
    const gchar *arg_id,
    GVariant *arg_notification,
    GCancellable *cancellable,
    GError **error);

void org_gtk_notifications_call_remove_notification (
    OrgGtkNotifications *proxy,
    const gchar *arg_app_id,
    const gchar *arg_id,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean org_gtk_notifications_call_remove_notification_finish (
    OrgGtkNotifications *proxy,
    GAsyncResult *res,
    GError **error);

gboolean org_gtk_notifications_call_remove_notification_sync (
    OrgGtkNotifications *proxy,
    const gchar *arg_app_id,
    const gchar *arg_id,
    GCancellable *cancellable,
    GError **error);



/* ---- */

#define TYPE_ORG_GTK_NOTIFICATIONS_PROXY (org_gtk_notifications_proxy_get_type ())
#define ORG_GTK_NOTIFICATIONS_PROXY(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), TYPE_ORG_GTK_NOTIFICATIONS_PROXY, OrgGtkNotificationsProxy))
#define ORG_GTK_NOTIFICATIONS_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), TYPE_ORG_GTK_NOTIFICATIONS_PROXY, OrgGtkNotificationsProxyClass))
#define ORG_GTK_NOTIFICATIONS_PROXY_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), TYPE_ORG_GTK_NOTIFICATIONS_PROXY, OrgGtkNotificationsProxyClass))
#define IS_ORG_GTK_NOTIFICATIONS_PROXY(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), TYPE_ORG_GTK_NOTIFICATIONS_PROXY))
#define IS_ORG_GTK_NOTIFICATIONS_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), TYPE_ORG_GTK_NOTIFICATIONS_PROXY))

typedef struct _OrgGtkNotificationsProxy OrgGtkNotificationsProxy;
typedef struct _OrgGtkNotificationsProxyClass OrgGtkNotificationsProxyClass;
typedef struct _OrgGtkNotificationsProxyPrivate OrgGtkNotificationsProxyPrivate;

struct _OrgGtkNotificationsProxy
{
  /*< private >*/
  GDBusProxy parent_instance;
  OrgGtkNotificationsProxyPrivate *priv;
};

struct _OrgGtkNotificationsProxyClass
{
  GDBusProxyClass parent_class;
};

GType org_gtk_notifications_proxy_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (OrgGtkNotificationsProxy, g_object_unref)
#endif

void org_gtk_notifications_proxy_new (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
OrgGtkNotifications *org_gtk_notifications_proxy_new_finish (
    GAsyncResult        *res,
    GError             **error);
OrgGtkNotifications *org_gtk_notifications_proxy_new_sync (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);

void org_gtk_notifications_proxy_new_for_bus (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
OrgGtkNotifications *org_gtk_notifications_proxy_new_for_bus_finish (
    GAsyncResult        *res,
    GError             **error);
OrgGtkNotifications *org_gtk_notifications_proxy_new_for_bus_sync (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);


/* ---- */

#define TYPE_ORG_GTK_NOTIFICATIONS_SKELETON (org_gtk_notifications_skeleton_get_type ())
#define ORG_GTK_NOTIFICATIONS_SKELETON(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), TYPE_ORG_GTK_NOTIFICATIONS_SKELETON, OrgGtkNotificationsSkeleton))
#define ORG_GTK_NOTIFICATIONS_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), TYPE_ORG_GTK_NOTIFICATIONS_SKELETON, OrgGtkNotificationsSkeletonClass))
#define ORG_GTK_NOTIFICATIONS_SKELETON_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), TYPE_ORG_GTK_NOTIFICATIONS_SKELETON, OrgGtkNotificationsSkeletonClass))
#define IS_ORG_GTK_NOTIFICATIONS_SKELETON(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), TYPE_ORG_GTK_NOTIFICATIONS_SKELETON))
#define IS_ORG_GTK_NOTIFICATIONS_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), TYPE_ORG_GTK_NOTIFICATIONS_SKELETON))

typedef struct _OrgGtkNotificationsSkeleton OrgGtkNotificationsSkeleton;
typedef struct _OrgGtkNotificationsSkeletonClass OrgGtkNotificationsSkeletonClass;
typedef struct _OrgGtkNotificationsSkeletonPrivate OrgGtkNotificationsSkeletonPrivate;

struct _OrgGtkNotificationsSkeleton
{
  /*< private >*/
  GDBusInterfaceSkeleton parent_instance;
  OrgGtkNotificationsSkeletonPrivate *priv;
};

struct _OrgGtkNotificationsSkeletonClass
{
  GDBusInterfaceSkeletonClass parent_class;
};

GType org_gtk_notifications_skeleton_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (OrgGtkNotificationsSkeleton, g_object_unref)
#endif

OrgGtkNotifications *org_gtk_notifications_skeleton_new (void);


G_END_DECLS

#endif /* __SHELL_DBUS_H__ */
